// This file is coded in ES5 and CommonJS to be compatible with
// `create-locale`.

const forEach = require('lodash/forEach')

const messages = {
  keyValue: '{key}: {value}',

  statusConnecting: 'Connecting',
  statusDisconnected: 'Disconnected',
  statusLoading: 'Loading…',
  errorPageNotFound: 'Page not found',
  errorNoSuchItem: 'No such item',
  errorUnknownItem: 'Unknown {type}',
  generateNewMacAddress: 'Generate new MAC addresses',
  memoryFree: '{memoryFree} RAM free',
  utcDate: 'UTC date',
  utcTime: 'UTC time',
  date: 'Date',
  notifications: 'Notifications',
  noNotifications: 'No notifications so far.',
  notificationNew: 'NEW!',
  moreDetails: 'More details',
  messageSubject: 'Subject',
  messageFrom: 'From',
  messageReply: 'Reply',
  sr: 'SR',
  tryXoa: 'Try XOA for free and deploy it here.',
  notInstalled: 'Not installed',

  editableLongClickPlaceholder: 'Long click to edit',
  editableClickPlaceholder: 'Click to edit',
  browseFiles: 'Browse files',
  showLogs: 'Show logs',
  noValue: 'None',
  compression: 'Compression',
  core: 'Core',
  cpu: 'CPU',
  multipathing: 'Multipathing',
  multipathingDisabled: 'Multipathing disabled',
  enableMultipathing: 'Enable multipathing',
  disableMultipathing: 'Disable multipathing',
  enableAllHostsMultipathing: 'Enable multipathing for all hosts',
  disableAllHostsMultipathing: 'Disable multipathing for all hosts',
  paths: 'Paths',
  pbdDisconnected: 'PBD disconnected',
  hasInactivePath: 'Has an inactive path',
  pools: 'Pools',
  remotes: 'Remotes',
  schedulerGranularity: 'Scheduler granularity',
  socket: 'Socket',
  type: 'Type',
  restore: 'Restore',
  delete: 'Delete',
  vms: 'VMs',
  cpusMax: 'Max vCPUs',
  metadata: 'Metadata',
  chooseBackup: 'Choose a backup',
  temporarilyDisabled: 'Temporarily disabled',
  clickToShowError: 'Click to show error',
  backupJobs: 'Backup jobs',
  iscsiSessions: '({ nSessions, number }) iSCSI session{nSessions, plural, one {} other {s}}',
  requiresAdminPermissions: 'Requires admin permissions',
  proxy: 'Proxy',
  proxies: 'Proxies',
  name: 'Name',
  value: 'Value',
  address: 'Address',
  vm: 'VM',
  destinationSR: 'Destination SR',
  destinationNetwork: 'Destination network',
  dhcp: 'DHCP',
  ip: 'IP',
  static: 'Static',
  user: 'User',
  deletedUser: 'deleted ({ name })',
  networkConfiguration: 'Network configuration',
  integrity: 'Integrity',
  altered: 'Altered',
  missing: 'Missing',
  verified: 'Verified',
  snapshotMode: 'Snapshot mode',
  normal: 'Normal',
  withMemory: 'With memory',
  offline: 'Offline',
  noLicenseAvailable: 'No license available',
  emailPlaceholderExample: 'Email address, e.g.: it@company.net',
  unknown: 'Unknown',
  upgradesAvailable: 'Upgrades available',
  advancedSettings: 'Advanced settings',
  forceUpgrade: 'Force upgrade',
  txChecksumming: 'TX checksumming',
  unknownSize: 'Unknown size',
  installedCertificates: 'Installed certificates',
  expiry: 'Expiry',
  fingerprint: 'Fingerprint',
  certificate: 'Certificate (PEM)',
  certificateChain: 'Certificate chain (PEM)',
  privateKey: 'Private key (PKCS#8)',
  installNewCertificate: 'Install new certificate',
  replaceExistingCertificate: 'Replace existing certificate',
  customFields: 'Custom fields',
  addCustomField: 'Add custom field',
  editCustomField: 'Edit custom field',
  deleteCustomField: 'Delete custom field',

  // ----- Modals -----
  alertOk: 'OK',
  confirmOk: 'OK',
  formOk: 'OK',
  genericCancel: 'Cancel',
  enterConfirmText: 'Enter the following text to confirm:',

  // ----- Filters -----
  onError: 'On error',
  successful: 'Successful',
  filterOutShortTasks: 'Hide short tasks',
  filterOnlyManaged: 'Managed disks',
  filterOnlyOrphaned: 'Orphaned disks',
  filterOnlyRegular: 'Normal disks',
  filterOnlyRunningVms: 'Running VMs',
  filterOnlySnapshots: 'Snapshot disks',
  filterOnlyUnmanaged: 'Unmanaged disks',
  filterSaveAs: 'Save…',
  filterSyntaxLinkTooltip: 'Explore the search syntax in the documentation',
  filterVifsOnlyConnected: 'Connected VIFs',
  filterVifsOnlyDisconnected: 'Disconnected VIFs',
  filterRemotesOnlyConnected: 'Connected remotes',
  filterRemotesOnlyDisconnected: 'Disconnected remotes',

  // ----- Copiable component -----
  copyToClipboard: 'Copy to clipboard',
  copyUuid: 'Copy {uuid}',

  // ----- Pills -----
  pillMaster: 'Master',

  // ----- Titles -----
  homePage: 'Home',
  homeVmPage: 'VMs',
  homeHostPage: 'Hosts',
  homePoolPage: 'Pools',
  homeTemplatePage: 'Templates',
  homeSrPage: 'Storage',
  dashboardPage: 'Dashboard',
  overviewDashboardPage: 'Overview',
  overviewVisualizationDashboardPage: 'Visualizations',
  overviewStatsDashboardPage: 'Statistics',
  overviewHealthDashboardPage: 'Health',
  selfServicePage: 'Self service',
  backupPage: 'Backup',
  jobsPage: 'Jobs',
  xoaPage: 'XOA',
  updatePage: 'Updates',
  licensesPage: 'Licenses',
  notificationsPage: 'Notifications',
  supportPage: 'Support',
  settingsPage: 'Settings',
  settingsAuditPage: 'Audit',
  settingsServersPage: 'Servers',
  settingsUsersPage: 'Users',
  settingsGroupsPage: 'Groups',
  settingsAclsPage: 'ACLs',
  settingsPluginsPage: 'Plugins',
  settingsLogsPage: 'Logs',
  settingsCloudConfigsPage: 'Cloud configs',
  settingsIpsPage: 'IPs',
  settingsConfigPage: 'Config',
  aboutPage: 'About',
  aboutXoaPlan: 'About XO {xoaPlan}',
  newMenu: 'New',
  taskMenu: 'Tasks',
  taskPage: 'Tasks',
  newNetworkPage: 'Network',
  newVmPage: 'VM',
  newSrPage: 'Storage',
  newServerPage: 'Server',
  newImport: 'Import',
  xosan: 'XOSAN',
  backupOverviewPage: 'Overview',
  backupNewPage: 'New',
  backupRemotesPage: 'Remotes',
  backupRestorePage: 'Restore',
  backupFileRestorePage: 'File restore',
  schedule: 'Schedule',
  backup: 'Backup',
  rollingSnapshot: 'Rolling Snapshot',
  deltaBackup: 'Delta Backup',
  disasterRecovery: 'Disaster Recovery',
  continuousReplication: 'Continuous Replication',
  backupType: 'Backup type',
  poolMetadata: 'Pool metadata',
  xoConfig: 'XO config',
  backupVms: 'Backup VMs',
  backupMetadata: 'Backup metadata',
  jobsOverviewPage: 'Overview',
  jobsNewPage: 'New',
  jobsSchedulingPage: 'Scheduling',
  customJob: 'Custom Job',
  userPage: 'User',
  xoa: 'XOA',

  // ----- Support -----
  noSupport: 'No support',
  freeUpgrade: 'Free upgrade!',
  checkXoa: 'Check XOA',
  xoaCheck: 'XOA check',
  closeTunnel: 'Close tunnel',
  createSupportTicket: 'Create a support ticket',
  openTunnel: 'Open tunnel',
  supportCommunity: 'The XOA check and the support tunnel are available in XOA.',
  supportTunnel: 'Support tunnel',
  supportTunnelClosed: 'The support tunnel is closed.',

  // ----- Sign out -----
  signOut: 'Sign out',

  // ----- User Profile -----
  editUserProfile: 'Edit my settings {username}',

  // ----- Home view ------
  allVms: 'All VMs',
  backedUpVms: 'Backed up VMs',
  notBackedUpVms: 'Not backed up VMs',
  homeFetchingData: 'Fetching data…',
  homeWelcome: 'Welcome to Xen Orchestra!',
  homeWelcomeText: 'Add your XenServer hosts or pools',
  homeConnectServerText: 'Some XenServers have been registered but are not connected',
  homeHelp: 'Want some help?',
  homeAddServer: 'Add server',
  homeConnectServer: 'Connect servers',
  homeOnlineDoc: 'Online doc',
  homeProSupport: 'Pro support',
  homeNoVms: 'There are no VMs!',
  homeNoVmsOr: 'Or…',
  homeImportVm: 'Import VM',
  homeImportVmMessage: 'Import an existing VM in xva format',
  homeRestoreBackup: 'Restore a backup',
  homeRestoreBackupMessage: 'Restore a backup from a remote store',
  homeNewVmMessage: 'This will create a new VM',
  homeFilters: 'Filters',
  homeNoMatches: 'No results! Click here to reset your filters',
  homeTypePool: 'Pool',
  homeTypeHost: 'Host',
  homeTypeVm: 'VM',
  homeTypeSr: 'SR',
  homeTypeVmTemplate: 'Template',
  homeSort: 'Sort',
  homeAllPools: 'Pools',
  homeAllHosts: 'Hosts',
  homeAllTags: 'Tags',
  homeAllResourceSets: 'Resource sets',
  homeNewVm: 'New VM',
  homeFilterNone: 'None',
  homeFilterDisabledHosts: 'Disabled hosts',
  homeFilterPendingVms: 'Pending VMs',
  homeFilterHvmGuests: 'HVM guests',
  homeSortBy: 'Sort by',
  homeSortByCpus: 'CPUs',
  homeSortByStartTime: 'Start time',
  homeSortByName: 'Name',
  homeSortByPowerstate: 'Power state',
  homeSortByRAM: 'RAM',
  homeSortByShared: 'Shared/Not shared',
  homeSortBySize: 'Size',
  homeSortByType: 'Type',
  homeSortByUsage: 'Usage',
  homeSortVmsBySnapshots: 'Snapshots',
  homeSortByContainer: 'Container',
  homeSortByPool: 'Pool',
  homeDisplayedItems: '{displayed, number}x {icon} (of {total, number})',
  homeSelectedItems: '{selected, number}x {icon} selected (of {total, number})',
  homeMore: 'More',
  homeMigrateTo: 'Migrate to…',
  homeMissingPatches: 'Missing patches',
  homePoolMaster: 'Master:',
  homeResourceSet: 'Resource set: {resourceSet}',
  highAvailability: 'High Availability',
  powerState: 'Power state',
  srSharedType: 'Shared {type}',
  warningHostTimeTooltip: 'Host time and XOA time are not consistent with each other',
  selectExistingTags: 'Select from existing tags',
  sortByDisksUsage: 'Disks usage',

  // ----- Home snapshots -----
  snapshotVmsName: 'Name',
  snapshotVmsDescription: 'Description',

  // ----- Common components -----
  sortedTableAllItemsSelected: 'All of them are selected ({nItems, number})',
  sortedTableNoItems: 'No items found',
  sortedTableNumberOfFilteredItems: '{nFiltered, number} of {nTotal, number} items',
  sortedTableNumberOfItems: '{nTotal, number} items',
  sortedTableNumberOfSelectedItems: '{nSelected, number} selected',
  sortedTableSelectAllItems: 'Click here to select all items',
  chooseCompressionGzipOption: 'GZIP (very slow)',
  chooseCompressionZstdOption: 'Zstd (fast, XCP-ng only)',

  // ----- state -----
  state: 'State',
  stateDisabled: 'Disabled',
  stateEnabled: 'Enabled',

  // ----- Labels -----
  labelDisk: 'Disk',
  labelMerge: 'Merge',
  labelSize: 'Size',
  labelSpeed: 'Speed',
  labelSr: 'SR',
  labelTransfer: 'Transfer',
  labelVm: 'VM',

  // ----- Forms -----
  formCancel: 'Cancel',
  formCreate: 'Create',
  formDescription: 'Description',
  formEdit: 'Edit',
  formId: 'ID',
  formName: 'Name',
  formReset: 'Reset',
  formSave: 'Save',
  formNotes: 'Notes',
  add: 'Add',
  selectAll: 'Select all',
  remove: 'Remove',
  preview: 'Preview',
  action: 'Action',
  item: 'Item',
  noSelectedValue: 'No selected value',
  selectSubjects: 'Choose user(s) and/or group(s)',
  selectObjects: 'Select object(s)…',
  selectRole: 'Choose a role',
  selectHosts: 'Select host(s)…',
  selectHostsVms: 'Select object(s)…',
  selectNetworks: 'Select network(s)…',
  selectPifs: 'Select PIF(s)…',
  selectPools: 'Select pool(s)…',
  selectRemotes: 'Select remote(s)…',
  selectProxies: 'Select proxy(ies)…',
  selectProxy: 'Select proxy…',
  selectResourceSets: 'Select resource set(s)…',
  selectResourceSetsVmTemplate: 'Select template(s)…',
  selectResourceSetsSr: 'Select SR(s)…',
  selectResourceSetsNetwork: 'Select network(s)…',
  selectResourceSetsVdi: 'Select disk(s)…',
  selectSshKey: 'Select SSH key(s)…',
  selectSrs: 'Select SR(s)…',
  selectVms: 'Select VM(s)…',
  selectVmSnapshots: 'Select snapshot(s)…',
  selectVmTemplates: 'Select VM template(s)…',
  selectTags: 'Select tag(s)…',
  selectVdis: 'Select disk(s)…',
  selectTimezone: 'Select timezone…',
  selectIp: 'Select IP(s)…',
  selectIpPool: 'Select IP pool(s)…',
  selectVgpuType: 'Select VGPU type(s)…',
  fillOptionalInformations: 'Fill information (optional)',
  selectTableReset: 'Reset',
  selectCloudConfigs: 'Select cloud config(s)…',

  // --- Dates/Scheduler ---

  schedulingMonth: 'Month',
  schedulingDay: 'Day',
  schedulingSetWeekDayMode: 'Switch to week days',
  schedulingSetMonthDayMode: 'Switch to month days',
  schedulingHour: 'Hour',
  schedulingMinute: 'Minute',
  selectTableAllMonth: 'Every month',
  selectTableAllDay: 'Every day',
  selectTableAllHour: 'Every hour',
  selectTableAllMinute: 'Every minute',
  timezonePickerUseLocalTime: 'Web browser timezone',
  serverTimezoneOption: 'Server timezone ({value})',
  cronPattern: 'Cron Pattern:',
  successfulJobCall: 'Successful',
  failedJobCall: 'Failed',
  jobCallSkipped: 'Skipped',
  jobCallInProgess: 'In progress',
  jobTransferredDataSize: 'Transfer size:',
  jobTransferredDataSpeed: 'Transfer speed:',
  operationSize: 'Size',
  operationSpeed: 'Speed',
  exportType: 'Type',
  jobMergedDataSize: 'Merge size:',
  jobMergedDataSpeed: 'Merge speed:',
  allJobCalls: 'All',
  job: 'Job',
  jobModalTitle: 'Job {job}',
  jobId: 'ID',
  jobType: 'Type',
  jobName: 'Name',
  jobModes: 'Modes',
  jobNamePlaceholder: 'Name of your job (forbidden: "_")',
  jobStart: 'Start',
  jobEnd: 'End',
  jobDuration: 'Duration',
  jobStatus: 'Status',
  jobAction: 'Action',
  jobTag: 'Tag',
  jobScheduling: 'Scheduling',
  jobTimezone: 'Timezone',
  jobServerTimezone: 'Server',
  runJob: 'Run job',
  cancelJob: 'Cancel job',
  runJobVerbose: 'Onetime job started. See overview for logs.',
  jobEdit: 'Edit job',
  jobDelete: 'Delete',
  jobFinished: 'Finished',
  jobInterrupted: 'Interrupted',
  jobStarted: 'Started',
  jobFailed: 'Failed',
  jobSkipped: 'Skipped',
  jobSuccess: 'Successful',
  allTasks: 'All',
  taskStart: 'Start',
  taskEnd: 'End',
  taskDuration: 'Duration',
  taskSuccess: 'Successful',
  taskFailed: 'Failed',
  taskSkipped: 'Skipped',
  taskStarted: 'Started',
  taskInterrupted: 'Interrupted',
  taskTransferredDataSize: 'Transfer size',
  taskTransferredDataSpeed: 'Transfer speed',
  taskMergedDataSize: 'Merge size',
  taskMergedDataSpeed: 'Merge speed',
  taskError: 'Error',
  taskEstimatedEnd: 'Estimated end',
  taskReason: 'Reason',
  saveBackupJob: 'Save',
  deleteBackupSchedule: 'Remove backup job',
  deleteBackupScheduleQuestion: 'Are you sure you want to delete this backup job?',
  deleteSelectedJobs: 'Delete selected jobs',
  scheduleEnableAfterCreation: 'Enable immediately after creation',
  scheduleEditMessage: 'You are editing schedule {name} ({id}). Saving will override previous schedule state.',
  jobEditMessage: 'You are editing job {name} ({id}). Saving will override previous job state.',
  scheduleEdit: 'Edit schedule',
  missingBackupName: "A name is required to create the backup's job!",
  missingVms: 'Missing VMs!',
  missingBackupMode: 'You need to choose a backup mode!',
  missingRemotes: 'Missing remotes!',
  missingSrs: 'Missing SRs!',
  missingPools: 'Missing pools!',
  missingSchedules: 'Missing schedules!',
  missingRetentions: 'The modes need at least a schedule with retention higher than 0',
  missingExportRetention: 'The Backup mode and the Delta Backup mode require backup retention to be higher than 0!',
  missingCopyRetention: 'The CR mode and The DR mode require replication retention to be higher than 0!',
  missingSnapshotRetention: 'The Rolling Snapshot mode requires snapshot retention to be higher than 0!',
  deltaChainRetentionWarning: 'Either the full backup interval or the backup retention should be lower than 50.',
  retentionNeeded: 'Requires one retention to be higher than 0!',
  newScheduleError: 'Invalid schedule',
  createRemoteMessage: 'No remotes found, please click on the remotes settings button to create one!',
  remotesSettings: 'Remotes settings',
  pluginsSettings: 'Plugins settings',
  pluginsWarning: 'To receive the report, the plugins backup-reports and transport-email need to be loaded.',
  scheduleAdd: 'Add a schedule',
  scheduleDelete: 'Delete',
  scheduleRun: 'Run schedule',
  deleteSelectedSchedules: 'Delete selected schedules',
  noScheduledJobs: 'No scheduled jobs.',
  legacySnapshotsLink: 'You can delete all your legacy backup snapshots.',
  newSchedule: 'New schedule',
  noSchedules: 'No schedules found',
  jobActionPlaceHolder: 'Select an xo-server API command',
  jobTimeoutPlaceHolder: 'Timeout (number of seconds after which a VM is considered failed)',
  jobSchedules: 'Schedules',
  jobScheduleNamePlaceHolder: 'Name of your schedule',
  jobScheduleJobPlaceHolder: 'Select a job',
  jobOwnerPlaceholder: 'Job owner',
  jobUserNotFound: "This job's creator no longer exists",
  redirectToMatchingVms: 'Click here to see the matching VMs',
  noMatchingVms: 'There are no matching VMs!',
  allMatchingVms: '{icon} See the matching VMs ({nMatchingVms, number})',
  runBackupNgJobConfirm: 'Are you sure you want to run {name} ({id})?',
  runBackupJobWarningNVms: 'This job will backup {nVms, number} VM{nVms, plural, one {} other {s}}.',
  cancelJobConfirm: 'Are you sure you want to cancel {name} ({id})?',
  scheduleDstWarning:
    'If your country participates in DST, it is advised that you avoid scheduling jobs at the time of change. e.g. 2AM to 3AM for US.',

  // ------ New backup -----
  newBackupAdvancedSettings: 'Advanced settings',
  newBackupSettings: 'Settings',
  reportWhenAlways: 'Always',
  reportWhenFailure: 'Failure',
  reportWhenNever: 'Never',
  reportRecipients: 'Report recipients',
  reportWhen: 'Report when',
  concurrency: 'Concurrency',
  newBackupSelection: 'Select your backup type:',
  snapshotRetention: 'Snapshot retention',
  backupName: 'Name',
  checkpointSnapshot: 'Checkpoint snapshot',
  offlineSnapshot: 'Offline snapshot',
  offlineBackup: 'Offline backup',
  offlineBackupInfo: 'Export VMs without snapshotting them. The VMs will be shutdown during the export.',
  timeout: 'Timeout',
  timeoutInfo: 'Number of hours after which a job is considered failed',
  fullBackupInterval: 'Full backup interval',
  forceFullBackup: 'Force full backup',
  timeoutUnit: 'In hours',
  dbAndDrRequireEnterprisePlan: 'Delta Backup and DR require an Enterprise plan',
  crRequiresPremiumPlan: 'CR requires a Premium plan',
  smartBackupModeTitle: 'Smart mode',
  backupTargetRemotes: 'Target remotes (for export)',
  backupTargetSrs: 'Target SRs (for replication)',
  localRemoteWarningTitle: 'Local remote selected',
  crOnThickProvisionedSrWarning:
    'Tip: Using thin-provisioned storage will consume less space. Please click on the icon to get more information',
  vmsOnThinProvisionedSrTip:
    'Tip: Creating VMs on thin-provisioned storage will consume less space. Please click on the icon to get more information',
  deltaBackupOnOutdatedXenServerWarning: 'Delta Backup and Continuous Replication require at least XenServer 6.5.',
  backupNgLinkToDocumentationMessage: 'Click for more information about the backup methods.',
  localRemoteWarningMessage: 'Warning: Local remotes will use limited XOA disk space. Only for advanced users.',
  editBackupVmsTitle: 'VMs',
  editBackupSmartStatusTitle: 'VMs statuses',
  editBackupSmartResidentOn: 'Resident on',
  editBackupSmartNotResidentOn: 'Not resident on',
  editBackupSmartPools: 'Pools',
  editBackupSmartTags: 'Tags',
  sampleOfMatchingVms: 'Sample of matching VMs',
  backupReplicatedVmsInfo:
    'Replicated VMs (VMs with Continuous Replication or Disaster Recovery tag) must be excluded!',
  editBackupSmartTagsTitle: 'VMs Tags',
  editBackupSmartExcludedTagsTitle: 'Excluded VMs tags',
  deleteOldBackupsFirst: 'Delete first',
  deleteOldBackupsFirstMessage:
    'Delete old backups before backing up the VMs. If the new backup fails, you will lose your old backups.',
  customTag: 'Custom tag',
  editJobNotFound: "The job you're trying to edit wasn't found",

  // ------ New Remote -----
  newRemote: 'New file system remote',
  remoteTypeLocal: 'Local',
  remoteTypeNfs: 'NFS',
  remoteTypeSmb: 'SMB',
  remoteTypeS3: 'Amazon Web Services S3 (beta)',
  remoteType: 'Type',
  remoteSmbWarningMessage:
    'SMB remotes are meant to work with Windows Server. For other systems (Linux Samba, which means almost all NAS), please use NFS.',
  remoteTestTip: 'Test your remote',
  testRemote: 'Test remote',
  remoteTestFailure: 'Test failed for {name}',
  remoteTestSuccess: 'Test passed for {name}',
  remoteTestError: 'Error',
  remoteTestStep: 'Test step',
  remoteTestName: 'Test name',
  remoteTestNameFailure: 'Remote name already exists!',
  remoteTestSuccessMessage: 'The remote appears to work correctly',
  remoteConnectionFailed: 'Connection failed',

  // ------ Backup job -----

  confirmDeleteBackupJobsTitle: 'Delete backup job{nJobs, plural, one {} other {s}}',
  confirmDeleteBackupJobsBody:
    'Are you sure you want to delete {nJobs, number} backup job{nJobs, plural, one {} other {s}}?',
  runBackupJob: 'Run backup job once',

  // ------ Remote -----
  remoteName: 'Name',
  remotePath: 'Path',
  remoteState: 'State',
  remoteDevice: 'Device',
  remoteDisk: 'Disk (Used / Total)',
  remoteSpeed: 'Speed (Write / Read)',
  remoteSpeedInfo: 'Read and write rate speed performed during latest test',
  remoteOptions: 'Options',
  remoteShare: 'Share',
  remoteAuth: 'Auth',
  remoteDeleteTip: 'Delete',
  remoteDeleteSelected: 'Delete selected remotes',
  remoteMyNamePlaceHolder: 'Name',
  remoteLocalPlaceHolderPath: '/path/to/backup',
  remoteNfsPlaceHolderHost: 'Host',
  remoteNfsPlaceHolderPort: 'Port',
  remoteNfsPlaceHolderPath: 'path/to/backup',
  remoteNfsPlaceHolderOptions: 'Custom mount options',
  remoteSmbPlaceHolderRemotePath: 'Subfolder [path\\\\to\\\\backup]',
  remoteSmbPlaceHolderUsername: 'Username',
  remoteSmbPlaceHolderPassword: 'Password',
  remoteSmbPlaceHolderDomain: 'Domain',
  remoteSmbPlaceHolderAddressShare: '<address>\\\\<share>',
  remoteSmbPlaceHolderOptions: 'Custom mount options',
  remoteS3PlaceHolderBucket: 'AWS S3 bucket name',
  remoteS3PlaceHolderDirectory: 'Directory',
  remoteS3Region: 'Region, leave blank for default',
  remoteS3TooltipProtocol: 'Check if you want HTTP instead of HTTPS',
  remotePlaceHolderPassword: 'Password(fill to edit)',

  // ------ New Storage -----
  newSrTitle: 'Create a new SR',
  newSrGeneral: 'General',
  newSrTypeSelection: 'Select storage type:',
  newSrSettings: 'Settings',
  newSrUsage: 'Storage usage',
  newSrSummary: 'Summary',
  newSrHost: 'Host',
  newSrType: 'Type',
  newSrName: 'Name',
  newSrDescription: 'Description',
  newSrServer: 'Server',
  newSrPath: 'Path',
  newSrIqn: 'IQN',
  newSrLun: 'LUN',
  newSrNoHba: 'No HBA devices',
  newSrAuth: 'With auth.',
  newSrUsername: 'User name',
  newSrPassword: 'Password',
  newSrDevice: 'Device',
  newSrInUse: 'In use',
  newSrSize: 'Size',
  newSrCreate: 'Create',
  newSrNamePlaceHolder: 'Storage name',
  newSrDescPlaceHolder: 'Storage description',
  newSrIscsiAddressPlaceHolder: 'e.g 93.184.216.34 or iscsi.example.net',
  newSrNfsAddressPlaceHolder: 'e.g 93.184.216.34 or nfs.example.net',
  newSrSmbAddressPlaceHolder: 'e.g \\\\server\\sharename',
  newSrPortPlaceHolder: '[port]',
  newSrUsernamePlaceHolder: 'Username',
  newSrPasswordPlaceHolder: 'Password',
  newSrLvmDevicePlaceHolder: 'Device, e.g /dev/sda…',
  newSrLocalPathPlaceHolder: '/path/to/directory',
  newSrNfsDefaultVersion: 'Default NFS version',
  newSrNfsOptions: 'Comma delimited NFS options',
  newSrNfs: 'NFS version',
  noSharedZfsAvailable: 'No shared ZFS available',
  reattachNewSrTooltip: 'Reattach SR',
  srLocation: 'Storage location',

  // ------ New Network -----
  createNewNetworkNoPermission: 'You do not have permission to create a network',
  createNewNetworkOn: 'Create a new network on {select}',

  // ----- ACLs, Users, Groups ------
  subjectName: 'Users/Groups',
  objectName: 'Object',
  roleName: 'Role',
  aclCreate: 'Create',
  newGroupName: 'New group name',
  createGroup: 'Create group',
  syncLdapGroups: 'Synchronize LDAP groups',
  ldapPluginNotConfigured: 'Install and configure the auth-ldap plugin first',
  syncLdapGroupsWarning:
    'Are you sure you want to synchronize LDAP groups with XO? This may delete XO groups and their ACLs.',
  createGroupButton: 'Create',
  deleteGroup: 'Delete group',
  deleteGroupConfirm: 'Are you sure you want to delete this group?',
  deleteSelectedGroups: 'Delete selected groups',
  deleteGroupsModalTitle: 'Delete group{nGroups, plural, one {} other {s}}',
  deleteGroupsModalMessage:
    'Are you sure you want to delete {nGroups, number} group{nGroups, plural, one {} other {s}}?',
  removeUserFromGroup: 'Remove user from group',
  deleteUserConfirm: 'Are you sure you want to delete this user?',
  deleteUser: 'Delete user',
  deleteSelectedUsers: 'Delete selected users',
  deleteUsersModalTitle: 'Delete user{nUsers, plural, one {} other {s}}',
  deleteUsersModalMessage: 'Are you sure you want to delete {nUsers, number} user{nUsers, plural, one {} other {s}}?',
  noUser: 'No user',
  unknownUser: 'Unknown user',
  noGroupFound: 'No group found',
  groupNameColumn: 'Name',
  groupUsersColumn: 'Users',
  addUserToGroupColumn: 'Add user',
  userNameColumn: 'Username',
  userGroupsColumn: 'Member of',
  userCountGroups: '{nGroups, number} group{nGroups, plural, one {} other {s}}',
  userPermissionColumn: 'Permissions',
  userPasswordColumn: 'Password',
  userName: 'Username',
  userPassword: 'Password',
  createUserButton: 'Create',
  noUserFound: 'No user found',
  userLabel: 'User',
  adminLabel: 'Admin',
  noUserInGroup: 'No user in group',
  countUsers: '{users, number} user{users, plural, one {} other {s}}',
  selectPermission: 'Select permission',
  deleteAcl: 'Delete ACL',
  deleteSelectedAcls: 'Delete selected ACLs',
  deleteAclsModalTitle: 'Delete ACL{nAcls, plural, one {} other {s}}',
  deleteAclsModalMessage: 'Are you sure you want to delete {nAcls, number} ACL{nAcls, plural, one {} other {s}}?',

  // ----- Plugins ------
  noPlugins: 'No plugins found',
  autoloadPlugin: 'Auto-load at server start',
  savePluginConfiguration: 'Save configuration',
  deletePluginConfiguration: 'Delete configuration',
  pluginConfirmation: 'The test appears to be working.',
  pluginError: 'Plugin error',
  pluginTest: 'Plugin test',
  unknownPluginError: 'Unknown error',
  purgePluginConfiguration: 'Purge plugin configuration',
  purgePluginConfigurationQuestion: 'Are you sure you want to purge this configuration?',
  cancelPluginEdition: 'Cancel',
  pluginConfigurationSuccess: 'Plugin configuration',
  pluginConfigurationChanges: 'Plugin configuration successfully saved!',
  pluginConfigurationPresetTitle: 'Predefined configuration',
  pluginConfigurationChoosePreset: 'Choose a predefined configuration.',
  applyPluginPreset: 'Apply',
  disabledTestPluginTootltip: 'This plugin is not loaded',

  // ----- User preferences -----
  saveNewUserFilterErrorTitle: 'Save filter error',
  saveNewUserFilterErrorBody: 'Bad parameter: name must be given.',
  filterName: 'Name:',
  filterValue: 'Value:',
  saveNewFilterTitle: 'Save new filter',
  removeUserFilterTitle: 'Remove custom filter',
  removeUserFilterBody: 'Are you sure you want to remove the custom filter?',
  defaultFilter: 'Default filter',
  defaultFilters: 'Default filters',
  customFilters: 'Custom filters',
  customizeFilters: 'Customize filters',

  // ----- VM actions ------
  cantInterPoolCopy: 'Interpool copy requires at least Enterprise plan',
  copyExportedUrl: 'Copy the export URL of the VM',
  downloadVm: 'Download VM',
  startVmLabel: 'Start',
  startVmOnLabel: 'Start on…',
  startVmOnMissingHostTitle: 'No host selected',
  startVmOnMissingHostMessage: 'You must select a host',
  recoveryModeLabel: 'Recovery start',
  suspendVmLabel: 'Suspend',
  pauseVmLabel: 'Pause',
  stopVmLabel: 'Stop',
  forceShutdownVmLabel: 'Force shutdown',
  rebootVmLabel: 'Reboot',
  forceRebootVmLabel: 'Force reboot',
  deleteVmLabel: 'Delete',
  deleteSelectedVmsLabel: 'Delete selected VMs',
  migrateVmLabel: 'Migrate',
  snapshotVmLabel: 'Snapshot',
  exportVmLabel: 'Export',
  resumeVmLabel: 'Resume',
  copyVmLabel: 'Copy',
  cloneVmLabel: 'Clone',
  fastCloneVmLabel: 'Fast clone',
  vmConsoleLabel: 'Console',
  vmExportUrlValidity: 'The URL is valid once for a short period of time.',
  backupLabel: 'Backup',

  // ----- SR general tab -----
  baseCopyTooltip: '{n, number} base cop{n, plural, one {y} other {ies}} ({usage})',
  diskTooltip: '{name} ({usage})',
  snapshotsTooltip: '{n, number} snapshot{n, plural, one {} other {s}} ({usage})',
  vdiOnVmTooltip: '{name} ({usage}) on {vmName}',
  vdisTooltip: '{n, number} VDI{n, plural, one {} other {s}} ({usage})',

  // ----- SR advanced tab -----

  provisioning: 'Provisioning',
  srUnhealthyVdiDepth: 'Depth',
  srUnhealthyVdiNameLabel: 'Name',
  srUnhealthyVdiSize: 'Size',
  srUnhealthyVdiTitle: 'VDI to coalesce ({total, number})',
  srUnhealthyVdiUuid: 'UUID',

  // ----- SR stats tab -----

  srNoStats: 'No stats',
  statsIops: 'IOPS',
  statsIoThroughput: 'IO throughput',
  statsLatency: 'Latency',
  statsIowait: 'IOwait',

  // ----- SR actions -----
  srRescan: 'Rescan all disks',
  srReconnectAll: 'Connect to all hosts',
  srDisconnectAll: 'Disconnect from all hosts',
  srForget: 'Forget this SR',
  srsForget: 'Forget SRs',
  srRemoveButton: 'Remove this SR',
  srNoVdis: 'No VDIs in this storage',

  // ----- SR disks tab -----
  multipleActiveVdis: '{firstVdi} and {nVdis} more',
  noActiveVdi: 'No active VDI',

  // ----- Pool general -----
  poolTitleRamUsage: 'Pool RAM usage:',
  poolRamUsage: '{used} used of {total} ({free} free)',
  poolMaster: 'Master:',
  displayAllHosts: 'Display all hosts of this pool',
  displayAllStorages: 'Display all storage for this pool',
  displayAllVMs: 'Display all VMs of this pool',
  licenseRestrictions: 'License restrictions',
  licenseRestrictionsModalTitle: 'Warning: You are using a Free XenServer license',
  actionsRestricted: 'Some functionality is restricted.',
  counterRestrictionsOptions: 'You can:',
  counterRestrictionsOptionsXcp: 'upgrade to XCP-ng for free to get rid of these restrictions',
  counterRestrictionsOptionsXsLicense: 'or get a commercial Citrix license',
  // ----- Pool tabs -----
  hostsTabName: 'Hosts',
  vmsTabName: 'VMs',
  srsTabName: 'SRs',
  // ----- Pool advanced tab -----
  backupNetwork: 'Backup network',
  poolEditAll: 'Edit all',
  poolHaStatus: 'High Availability',
  poolHaEnabled: 'Enabled',
  poolHaDisabled: 'Disabled',
  poolGpuGroups: 'GPU groups',
  poolRemoteSyslogPlaceHolder: 'Logging host',
  setpoolMaster: 'Master',
  syslogRemoteHost: 'Remote syslog host',
  defaultMigrationNetwork: 'Default migration network',
  syncNetbox: 'Synchronize with Netbox',
  syncNetboxWarning: 'Are you sure you want to synchronize with Netbox?',
  // ----- Pool host tab -----
  hostNameLabel: 'Name',
  hostDescription: 'Description',
  noHost: 'No hosts',
  memoryLeftTooltip: '{used}% used ({free} free)',
  // ----- Pool network tab -----
  pif: 'PIF',
  poolNetworkAutomatic: 'Automatic',
  poolNetworkNameLabel: 'Name',
  poolNetworkDescription: 'Description',
  poolNetworkPif: 'PIFs',
  privateNetworks: 'Private networks',
  manage: 'Manage',
  poolNoNetwork: 'No networks',
  poolNetworkMTU: 'MTU',
  poolNetworkPifAttached: 'Connected',
  poolNetworkPifDetached: 'Disconnected',
  showPifs: 'Show PIFs',
  hidePifs: 'Hide PIFs',
  networkAutomaticTooltip: 'Network(s) selected by default for new VMs',
  // ----- Pool stats tab -----
  poolNoStats: 'No stats',
  poolAllHosts: 'All hosts',
  // ----- Pool actions ------
  addSrLabel: 'Add SR',
  addVmLabel: 'Add VM',
  addHostsLabel: 'Add hosts',
  missingPatchesPool:
    'The pool needs to install {nMissingPatches, number} patch{nMissingPatches, plural, one {} other {es}}. This operation may take a while.',
  missingPatchesHost:
    'The selected host{nHosts, plural, one {} other {s}} need{nHosts, plural, one {s} other {}} to install {nMissingPatches, number} patch{nMissingPatches, plural, one {} other {es}}. This operation may take a while.',
  patchUpdateNoInstall:
    'The selected host{nHosts, plural, one {} other {s}} cannot be added to the pool because the patches are not homogeneous.',
  addHostsErrorTitle: 'Adding host{nHosts, plural, one {} other {s}} failed',
  addHostNotHomogeneousErrorMessage: 'Host patches could not be homogenized.',
  disconnectServer: 'Disconnect',

  // ----- Host item ------
  noMoreMaintained: 'This host version is no longer maintained',

  // ----- Host actions ------
  disableMaintenanceMode: 'Disable maintenance mode',
  enableMaintenanceMode: 'Enable maintenance mode',
  startHostLabel: 'Start',
  stopHostLabel: 'Stop',
  enableHostLabel: 'Enable',
  disableHostLabel: 'Disable',
  restartHostAgent: 'Restart toolstack',
  forceRebootHostLabel: 'Force reboot',
  rebootHostLabel: 'Reboot',
  noHostsAvailableErrorTitle: 'Error while restarting host',
  noHostsAvailableErrorMessage:
    'Some VMs cannot be migrated without first rebooting this host. Please try force reboot.',
  failHostBulkRestartTitle: 'Error while restarting hosts',
  failHostBulkRestartMessage:
    '{failedHosts, number}/{totalHosts, number} host{failedHosts, plural, one {} other {s}} could not be restarted.',
  rebootUpdateHostLabel: 'Reboot to apply updates',
  emergencyModeLabel: 'Emergency mode',
  // ----- Host tabs -----
  storageTabName: 'Storage',
  patchesTabName: 'Patches',
  // ----- host stat tab -----
  statLoad: 'Load average',
  // ----- host advanced tab -----
  editHostIscsiIqnTitle: 'Edit iSCSI IQN',
  editHostIscsiIqnMessage:
    'Are you sure you want to edit the iSCSI IQN? This may result in failures connecting to existing SRs if the host is attached to iSCSI SRs.',
  hostTitleRamUsage: 'Host RAM usage:',
  maintenanceHostModalMessage:
    'Are you sure you want to enter maintenance mode? This will migrate all the VMs running on this host to other hosts of the pool.',
  maintenanceHostModalTitle: 'Maintenance mode',
  maintenanceHostTooltip: 'Evacuate and disable the host',
  memoryHostState: 'RAM: {memoryUsed} used of {memoryTotal} ({memoryFree} free)',
  hardwareHostSettingsLabel: 'Hardware',
  hyperThreading: 'Hyper-threading (SMT)',
  hyperThreadingNotAvailable: 'HT detection is only available on XCP-ng 7.6 and higher',
  hostAddress: 'Address',
  hostStatus: 'Status',
  hostBuildNumber: 'Build number',
  hostIscsiIqn: 'iSCSI IQN',
  hostIommuTooltip: 'PCI passthrough capable',
  hostNoIscsiSr: 'Not connected to an iSCSI SR',
  hostMultipathingSrs: 'Click to see concerned SRs',
  hostMultipathingPaths: '{nActives, number} of {nPaths, number} path{nPaths, plural, one {} other {s}}',
  hostMultipathingRequiredState:
    'This action will not be fulfilled if a VM is in a running state. Please ensure that all VMs are evacuated or stopped before performing this action!',
  hostMultipathingWarning:
    'The host{nHosts, plural, one {} other {s}} will lose their connection to the SRs. Do you want to continue?',
  hostXenServerVersion: 'Version',
  hostStatusEnabled: 'Enabled',
  hostStatusDisabled: 'Disabled',
  hostPowerOnMode: 'Power on mode',
  hostControlDomainMemory: 'Control domain memory',
  setControlDomainMemory: 'Set control domain memory',
  setControlDomainMemoryMessage:
    'Editing the control domain memory will immediately restart the host in order to apply the changes.',
  maintenanceModeRequired: 'The host needs to be in maintenance mode',
  hostStartedSince: 'Host uptime',
  hostStackStartedSince: 'Toolstack uptime',
  hostCpusModel: 'CPU model',
  hostGpus: 'GPUs',
  hostCpusNumber: 'Core (socket)',
  hostManufacturerinfo: 'Manufacturer info',
  hostBiosinfo: 'BIOS info',
  licenseHostSettingsLabel: 'License',
  hostLicenseType: 'Type',
  hostLicenseSocket: 'Socket',
  hostLicenseExpiry: 'Expiry',
  hostRemoteSyslog: 'Remote syslog',
  hostIommu: 'IOMMU',
  hostNoCertificateInstalled: 'No certificates installed on this host',
  supplementalPacks: 'Installed supplemental packs',
  supplementalPackNew: 'Install new supplemental pack',
  supplementalPackPoolNew: 'Install supplemental pack on every host',
  supplementalPackTitle: '{name} (by {author})',
  supplementalPackInstallStartedTitle: 'Installation started',
  supplementalPackInstallStartedMessage: 'Installing new supplemental pack…',
  supplementalPackInstallErrorTitle: 'Installation error',
  supplementalPackInstallErrorMessage: 'The installation of the supplemental pack failed.',
  supplementalPackInstallSuccessTitle: 'Installation success',
  supplementalPackInstallSuccessMessage: 'Supplemental pack successfully installed.',
  uniqueHostIscsiIqnInfo: 'The iSCSI IQN must be unique. ',
  // ----- Host net tabs -----
  networkCreateButton: 'Add a network',
  pifDeviceLabel: 'Device',
  pifNetworkLabel: 'Network',
  pifVlanLabel: 'VLAN',
  pifAddressLabel: 'Address',
  pifModeLabel: 'Mode',
  pifMacLabel: 'MAC',
  pifMtuLabel: 'MTU',
  pifSpeedLabel: 'Speed',
  pifStatusLabel: 'Status',
  pifInUse: 'This interface is currently in use',
  defaultLockingMode: 'Default locking mode',
  pifConfigureIp: 'Configure IP address',
  configIpErrorTitle: 'Invalid parameters',
  configIpErrorMessage: 'IP address and netmask required',
  staticIp: 'Static IP address',
  netmask: 'Netmask',
  dns: 'DNS',
  gateway: 'Gateway',
  // ----- Host storage tabs -----
  addSrDeviceButton: 'Add a storage',
  srType: 'Type',
  pbdDetails: 'PBD details',
  pbdStatus: 'Status',
  pbdStatusConnected: 'Connected',
  pbdStatusDisconnected: 'Disconnected',
  pbdConnect: 'Connect',
  pbdDisconnect: 'Disconnect',
  pbdForget: 'Forget',
  srShared: 'Shared',
  srNotShared: 'Not shared',
  pbdNoSr: 'No storage detected',
  // ----- Host patch tabs -----
  patchNameLabel: 'Name',
  patchUpdateButton: 'Install all patches',
  patchDescription: 'Description',
  patchVersion: 'Version',
  patchApplied: 'Applied date',
  patchSize: 'Size',
  patchNothing: 'No patches detected',
  patchReleaseDate: 'Release date',
  patchGuidance: 'Guidance',
  hostAppliedPatches: 'Applied patches',
  hostMissingPatches: 'Missing patches',
  hostUpToDate: 'Host up-to-date!',
  installAllPatchesTitle: 'Install all patches',
  installAllPatchesContent: 'To install all patches go to pool.',
  installAllPatchesRedirect: 'Go to pool',
  installAllPatchesOnHostContent: 'Are you sure you want to install all patches on this host?',
  patchRelease: 'Release',
  updatePluginNotInstalled:
    'An error occurred while fetching the patches. Please make sure the updater plugin is installed by running `yum install xcp-ng-updater` on the host.',
  showChangelog: 'Show changelog',
  changelog: 'Changelog',
  changelogPatch: 'Patch',
  changelogAuthor: 'Author',
  changelogDate: 'Date',
  changelogDescription: 'Description',
  // ----- Pool patch tabs -----
  install: 'Install',
  installPatchesTitle: 'Install patch{nPatches, plural, one {} other {es}}',
  installPatchesContent:
    'Are you sure you want to install {nPatches, number} patch{nPatches, plural, one {} other {es}}?',
  installPoolPatches: 'Install pool patches',
  confirmPoolPatch: 'Are you sure you want to install all the patches on this pool?',
  rollingPoolUpdate: 'Rolling pool update',
  rollingPoolUpdateMessage:
    'Are you sure you want to start a rolling pool update? Running VMs will be migrated back and forth and this can take a while.',
  poolNeedsDefaultSr: 'The pool needs a default SR to install the patches.',
  vmsHaveCds: '{nVms, number} VM{nVms, plural, one {} other {s}} {nVms, plural, one {has} other {have}} CDs',
  ejectCds: 'Eject CDs',
  // ----- Pool storage tabs -----
  defaultSr: 'Default SR',
  setAsDefaultSr: 'Set as default SR',
  setDefaultSr: 'Set default SR:',

  // ----- VM tabs -----
  generalTabName: 'General',
  statsTabName: 'Stats',
  consoleTabName: 'Console',
  containersTabName: 'Container',
  snapshotsTabName: 'Snapshots',
  logsTabName: 'Logs',
  advancedTabName: 'Advanced',
  networkTabName: 'Network',
  disksTabName: 'Disk{disks, plural, one {} other {s}}',

  powerStateHalted: 'Halted',
  powerStateRunning: 'Running',
  powerStateSuspended: 'Suspended',
  powerStatePaused: 'Paused',
  powerStateDisabled: 'Disabled',
  powerStateBusy: 'Busy',

  // ----- VM home -----
  vmCurrentStatus: 'Current status:',
  vmNotRunning: 'Not running',
  vmHaltedSince: 'Halted {ago}',

  // ----- VM general tab -----
  noToolsDetected: 'No Xen tools detected',
  managementAgentDetected: 'Management agent {version} detected',
  managementAgentOutOfDate: 'Management agent {version} out of date',
  managementAgentNotDetected: 'Management agent not detected',
  noIpv4Record: 'No IPv4 record',
  noIpRecord: 'No IP record',
  started: 'Started {ago}',
  created: 'Created on {date}',
  paraVirtualizedMode: 'Paravirtualization (PV)',
  hardwareVirtualizedMode: 'Hardware virtualization (HVM)',
  hvmModeWithPvDriversEnabled: 'Hardware virtualization with paravirtualization drivers enabled (PVHVM)',
  pvInPvhMode: 'PV inside a PVH container (PV in PVH)',
  windowsUpdateTools: 'Windows Update tools',

  // ----- VM stat tab -----
  statsCpu: 'CPU usage',
  statsMemory: 'Memory usage',
  statsNetwork: 'Network throughput',
  useStackedValuesOnStats: 'Stacked values',
  statDisk: 'Disk throughput',
  statLastTenMinutes: 'Last 10 minutes',
  statLastTwoHours: 'Last 2 hours',
  statLastDay: 'Last day',
  statLastWeek: 'Last week',
  statLastYear: 'Last year',

  // ----- VM console tab -----
  copyToClipboardLabel: 'Copy',
  ctrlAltDelButtonLabel: 'Ctrl+Alt+Del',
  ctrlAltDelConfirmation: 'Send Ctrl+Alt+Del to VM?',
  multilineCopyToClipboard: 'Multiline copy',
  tipLabel: 'Tip:',
  hideHeaderTooltip: 'Hide info',
  showHeaderTooltip: 'Show info',
  sendToClipboard: 'Send to clipboard',
  sshRootTooltip: 'Connect using external SSH tool as root',
  sshRootLabel: 'SSH',
  sshUserTooltip: 'Connect using external SSH tool as user…',
  sshUserLabel: 'SSH as…',
  sshUsernameLabel: 'SSH user name',
  remoteNeedClientTools: 'No IP address reported by client tools',
  rdp: 'RDP',
  rdpRootTooltip: 'Connect using external RDP tool',

  // ----- VM container tab -----
  containerName: 'Name',
  containerCommand: 'Command',
  containerCreated: 'Creation date',
  containerStatus: 'Status',
  containerAction: 'Action',
  noContainers: 'No existing containers',
  containerStop: 'Stop this container',
  containerStart: 'Start this container',
  containerPause: 'Pause this container',
  containerResume: 'Resume this container',
  containerRestart: 'Restart this container',

  // ----- VM disk tab -----
  rescanIsoSrs: 'Rescan all ISO SRs',
  vbdCreateDeviceButton: 'New disk',
  vdiAttachDevice: 'Attach disk',
  vdiAttachDeviceConfirm: 'The selected VDI is already attached to this VM. Are you sure you want to continue?',
  vdiBootOrder: 'Boot order',
  vdiNameLabel: 'Name',
  vdiNameDescription: 'Description',
  vdiPool: 'Pool',
  vdiTags: 'Tags',
  vdiSize: 'Size',
  vdiSr: 'SR',
  vdiVms: 'VMs',
  vdiMigrate: 'Migrate VDI',
  vdiMigrateSelectSr: 'Destination SR:',
  vdiMigrateNoSr: 'No SR',
  vdiMigrateNoSrMessage: 'A target SR is required to migrate a VDI',
  vdiForget: 'Forget',
  noControlDomainVdis: 'No VDIs attached to control domain',
  vbdBootableStatus: 'Boot flag',
  vbdDevice: 'Device',
  vbdStatus: 'Status',
  vbdStatusConnected: 'Connected',
  vbdStatusDisconnected: 'Disconnected',
  vbdConnect: 'Connect VBD',
  vbdDisconnect: 'Disconnect VBD',
  vbdBootable: 'Bootable',
  vbdReadonly: 'Readonly',
  vbdCreate: 'Create',
  vbdAttach: 'Attach',
  vbdNamePlaceHolder: 'Disk name',
  vbdSizePlaceHolder: 'Size',
  cdDriveNotInstalled: 'CD drive not completely installed',
  cdDriveInstallation: 'Stop and start the VM to install the CD drive',
  saveBootOption: 'Save',
  resetBootOption: 'Reset',
  destroySelectedVdis: 'Destroy selected VDIs',
  destroyVdi: 'Destroy VDI',
  exportVdi: 'Export VDI content',
  importVdi: 'Import VDI content',
  importVdiNoFile: 'No file selected',
  selectVdiMessage: 'Drop VHD file here',
  useQuotaWarning:
    'Creating this disk will use the disk space quota from the resource set {resourceSet} ({spaceLeft} left)',
  notEnoughSpaceInResourceSet: 'Not enough space in resource set {resourceSet} ({spaceLeft} left)',
  warningVdiSr: "The VDIs' SRs must either be shared or on the same host for the VM to be able to start.",
  removeSelectedVdisFromVm: 'Remove selected VDIs from this VM',
  removeVdiFromVm: 'Remove VDI from this VM',

  // ----- VM network tab -----

  editVifLockingMode: 'Edit locking mode',
  aclRuleAllow: 'Allow the traffic',
  aclRuleProtocol: 'Select a protocol',
  aclRulePort: 'Select a port',
  aclRuleIpRange: 'Select an IP or an IP range (CIDR format)',
  aclRuleDirection: 'Select a direction',
  aclRuleAllowField: 'Traffic Enabled/Disabled',
  aclRuleProtocolField: 'Protocol',
  aclRulePortField: 'Port',
  aclRuleIpRangeField: 'IP range (CIDR format)',
  aclRuleDirectionField: 'Direction',
  addRule: 'Add rule',
  deleteRule: 'Delete rule',
  hideRules: 'Hide rules',
  sdnControllerNotLoaded: 'SDN Controller must be loaded',
  showRules: 'Show rules',
  vifAclRules: 'Traffic rules',
  vifCreateDeviceButton: 'New device',
  vifDeviceLabel: 'Device',
  vifMacLabel: 'MAC address',
  vifMtuLabel: 'MTU',
  vifNetworkLabel: 'Network',
  vifRateLimitLabel: 'Rate limit (kB/s)',
  vifStatusLabel: 'Status',
  vifStatusConnected: 'Connected',
  vifStatusDisconnected: 'Disconnected',
  vifConnect: 'Connect',
  vifDisconnect: 'Disconnect',
  vifRemove: 'Remove',
  vifsRemove: 'Remove selected VIFs',
  vifIpAddresses: 'IP addresses',
  vifMacAutoGenerate: 'Auto-generated if empty',
  vifAllowedIps: 'Allowed IPs',
  selectIpFromIpPool: 'Select an IP',
  enterIp: 'Enter an IP',
  addAllowedIp: 'Add allowed IP',
  addIpError: 'Error while adding allowed IP',
  invalidIp: 'Invalid IP',
  vifNoIps: 'No IPs',
  vifLockingModeDisabled: 'VIF locking mode is disabled',
  vifLockingModeUnlocked: 'VIF locking mode is unlocked',
  vifLockingModeLocked: 'VIF locking mode is locked',
  networkDefaultLockingModeDisabled: 'Network default locking mode is disabled',
  networkDefaultLockingModeUnlocked: 'Network default locking mode is unlocked',
  vifLockedNetworkNoIps: 'Network locked and no IPs are allowed for this interface',
  vifUnlockedNetworkWithIps: 'Some IPs are unnecessarily set as allowed for this interface',
  vifUnknownNetwork: 'Unknown network',
  vifCreate: 'Create',

  // ----- VM snapshot tab -----
  noSnapshots: 'No snapshots',
  newSnapshotWithMemory: 'New snapshot with memory',
  newSnapshotWithMemoryConfirm:
    'Are you sure you want to create a snapshot with memory? This could take a while and the VM will be unusable during that time.',
  snapshotMemorySaved: 'Memory saved',
  snapshotCreateButton: 'New snapshot',
  tipCreateSnapshotLabel: 'Just click on the snapshot button to create one!',
  revertSnapshot: 'Revert VM to this snapshot',
  deleteSnapshot: 'Remove this snapshot',
  deleteSnapshots: 'Remove selected snapshots',
  copySnapshot: 'Create a VM from this snapshot',
  exportSnapshot: 'Export this snapshot',
  secureBoot: 'Secure boot',
  snapshotDate: 'Creation date',
  snapshotError: 'Snapshot error',
  snapshotName: 'Name',
  snapshotDescription: 'Description',
  snapshotQuiesce: 'Quiesced snapshot',
  vmRevertSuccessfulTitle: 'Revert successful',
  vmRevertSuccessfulMessage: 'VM successfully reverted',
  currentSnapshot: 'Current snapshot',

  // ----- VM backup tab -----
  goToBackupPage: 'Go to the backup page.',

  // ----- VM log tab -----
  logRemoveAll: 'Remove all logs',
  noLogs: 'No logs so far',
  logDate: 'Creation date',
  logName: 'Name',
  logContent: 'Content',
  logAction: 'Action',

  // ----- VM advanced tab -----
  vmRemoveButton: 'Remove',
  vmConvertToTemplateButton: 'Convert to template',
  vmSwitchVirtualizationMode: 'Convert to {mode}',
  vmVirtualizationModeModalTitle: 'Change virtualization mode',
  vmVirtualizationModeModalBody:
    "You must know what you are doing, because it could break your setup (if you didn't install the bootloader in the MBR while switching from PV to HVM, or even worse, in HVM to PV, if you don't have the correct PV args)",
  vmShareButton: 'Share',
  xenSettingsLabel: 'Xen settings',
  guestOsLabel: 'Guest OS',
  miscLabel: 'Misc',
  virtualizationMode: 'Virtualization mode',
  startDelayLabel: 'Start delay (seconds)',
  cpuMaskLabel: 'CPU mask',
  selectCpuMask: 'Select core(s)…',
  cpuWeightLabel: 'CPU weight',
  defaultCpuWeight: 'Default ({value, number})',
  cpuCapLabel: 'CPU cap',
  defaultCpuCap: 'Default ({value, number})',
  pvArgsLabel: 'PV args',
  managementAgentVersion: 'Management agent version',
  osName: 'OS name',
  osKernel: 'OS kernel',
  autoPowerOn: 'Auto power on',
  protectFromDeletion: 'Protect from accidental deletion',
  protectFromShutdown: 'Protect from accidental shutdown',
  ha: 'HA',
  nestedVirt: 'Nested virtualization',
  vmAffinityHost: 'Affinity host',
  vmVga: 'VGA',
  vmVideoram: 'Video RAM',
  vmNicType: 'NIC type',
  noAffinityHost: 'None',
  originalTemplate: 'Original template',
  unknownOsName: 'Unknown',
  unknownOsKernel: 'Unknown',
  unknownOriginalTemplate: 'Unknown',
  vmLimitsLabel: 'VM limits',
  resourceSet: 'Resource set',
  resourceSetNone: 'None',
  vmCpuLimitsLabel: 'CPU limits',
  vmCpuTopology: 'Topology',
  vmChooseCoresPerSocket: 'Default behavior',
  vmSocketsWithCoresPerSocket:
    '{nSockets, number} socket{nSockets, plural, one {} other {s}} with {nCores, number} core{nCores, plural, one {} other {s}} per socket',
  vmCoresPerSocketNone: 'None',
  vmCoresPerSocket: '{nCores, number} core{nCores, plural, one {} other {s}} per socket',
  vmCoresPerSocketNotDivisor: "Not a divisor of the VM's max CPUs",
  vmCoresPerSocketExceedsCoresLimit: 'The selected value exceeds the cores limit ({maxCores, number})',
  vmCoresPerSocketExceedsSocketsLimit: 'The selected value exceeds the sockets limit ({maxSockets, number})',
  vmHaDisabled: 'Disabled',
  vmMemoryLimitsLabel: 'Memory limits (min/max)',
  vmVgpu: 'vGPU',
  vmVgpus: 'GPUs',
  vmVgpuNone: 'None',
  vmAddVgpu: 'Add vGPU',
  vmSelectVgpuType: 'Select vGPU type',
  vmAcls: 'ACLs',
  vmAddAcls: 'Add ACLs',
  addAclsErrorTitle: 'Failed to add ACL(s)',
  addAclsErrorMessage: 'User(s)/group(s) and role are required.',
  removeAcl: 'Delete',
  moreAcls: '{nAcls, number} more…',
  vmBootFirmware: 'Boot firmware',
  vmDefaultBootFirmwareLabel: 'default (bios)',
  vmBootFirmwareWarningMessage:
    "You're about to change your boot firmware. This is still experimental in CH/XCP-ng 8.0. Are you sure you want to continue?",

  // ----- VM placeholders -----

  vmHomeNamePlaceholder: 'Long click to add a name',
  vmHomeDescriptionPlaceholder: 'Long click to add a description',

  // ----- Templates -----

  copyToTemplate: 'Copy to template',
  copyToTemplateMessage: 'Are you sure you want to copy this snapshot to a template?',
  templateHomeNamePlaceholder: 'Click to add a name',
  templateHomeDescriptionPlaceholder: 'Click to add a description',
  templateDelete: 'Delete template',
  templateDeleteModalTitle: 'Delete VM template{templates, plural, one {} other {s}}',
  templateDeleteModalBody:
    'Are you sure you want to delete {templates, plural, one {this} other {these}} template{templates, plural, one {} other {s}}?',
  failedToDeleteTemplatesTitle: 'Delete template{nTemplates, plural, one {} other {s}} failed',
  failedToDeleteTemplatesMessage:
    'Failed to delete {nTemplates, number} template{nTemplates, plural, one {} other {s}}.',
  deleteDefaultTemplatesTitle: 'Delete default template{nDefaultTemplates, plural, one {} other {s}}',
  deleteDefaultTemplatesMessage:
    'You are attempting to delete {nDefaultTemplates, number} default template{nDefaultTemplates, plural, one {} other {s}}. Do you want to continue?',

  // ----- Dashboard -----
  poolPanel: 'Pool{pools, plural, one {} other {s}}',
  hostPanel: 'Host{hosts, plural, one {} other {s}}',
  vmPanel: 'VM{vms, plural, one {} other {s}}',
  memoryStatePanel: 'RAM Usage:',
  usedMemory: 'Used Memory',
  totalMemory: 'Total Memory',
  totalCpus: 'CPUs Total',
  usedVCpus: 'Used vCPUs',
  usedSpace: 'Used Space',
  totalSpace: 'Total Space',
  cpuStatePanel: 'CPUs Usage',
  vmStatePanel: 'VMs Power state',
  vmStateHalted: 'Halted',
  vmStateOther: 'Other',
  vmStateRunning: 'Running',
  vmStateAll: 'All',
  taskStatePanel: 'Pending tasks',
  usersStatePanel: 'Users',
  srStatePanel: 'Storage state',
  ofUsage: '{usage} (of {total})',
  ofCpusUsage:
    '{nVcpus, number} vCPU{nVcpus, plural, one {} other {s}} (of {nCpus, number} CPU{nCpus, plural, one {} other {s}})',
  noSrs: 'No storage',
  srName: 'Name',
  srPool: 'Pool',
  srHost: 'Host',
  srFormat: 'Type',
  srSize: 'Size',
  srUsage: 'Usage',
  srUsed: 'used',
  srFree: 'free',
  srUsageStatePanel: 'Storage Usage',
  srTopUsageStatePanel: 'Top 5 SR Usage (in %)',
  notEnoughPermissionsError: 'Not enough permissions!',
  vmsStates: '{running, number} running ({halted, number} halted)',
  dashboardStatsButtonRemoveAll: 'Clear selection',
  dashboardStatsButtonAddAllHost: 'Add all hosts',
  dashboardStatsButtonAddAllVM: 'Add all VMs',
  dashboardSendReport: 'Send report',
  dashboardReport: 'Report',
  dashboardSendReportMessage: 'This will send a usage report to your configured emails.',
  dashboardSendReportInfo: 'The usage report and transport email plugins need to be loaded!',

  // --- Stats board --
  weekHeatmapData: '{value} {date, date, medium}',
  weekHeatmapNoData: 'No data.',
  weeklyHeatmap: 'Weekly Heatmap',
  weeklyCharts: 'Weekly Charts',
  weeklyChartsScaleInfo: 'Synchronize scale:',
  statsDashboardGenericErrorTitle: 'Stats error',
  statsDashboardGenericErrorMessage: 'There is no stats available for:',
  noSelectedMetric: 'No selected metric',
  statsDashboardSelectObjects: 'Select',
  metricsLoading: 'Loading…',

  // ----- Health -----
  deleteBackups: 'Delete backup{nBackups, plural, one {} other {s}}',
  deleteBackupsMessage:
    'Are you sure you want to delete {nBackups, number} backup{nBackups, plural, one {} other {s}}?',
  detachedBackups: 'Detached backups',
  detachedVmSnapshots: 'Detached VM snapshots',
  duplicatedMacAddresses: 'Duplicated MAC addresses',
  missingJob: 'Missing job',
  missingVm: 'Missing VM',
  missingVmInJob: 'This VM does not belong to this job',
  missingSchedule: 'Missing schedule',
  noDetachedBackups: 'No backups',
  noDuplicatedMacAddresses: 'No duplicated MAC addresses',
  reason: 'Reason',
  orphanedVdis: 'Orphan VDIs',
  orphanVdisTip: 'VDIs and VDI snapshots that are not attached to a VM',
  orphanedVms: 'Orphaned VMs snapshot',
  noOrphanedObject: 'No orphans',
  tooManySnapshots: 'Too many snapshots',
  tooManySnapshotsTip: 'VMs with more than the recommended amount of snapshots',
  noTooManySnapshotsObject: 'No VMs with too many snapshots',
  numberOfSnapshots: 'Number of snapshots',
  guestToolStatus: 'Guest Tools status',
  guestToolStatusTip: 'VMs with missing or outdated guest tools',
  noGuestToolStatusObject: 'All running VMs have up to date guest tools',
  guestToolStatusColumn: 'Status',
  deleteOrphanedVdi: 'Delete orphaned snapshot VDI',
  deleteSelectedOrphanedVdis: 'Delete selected orphaned snapshot VDIs',
  vdisOnControlDomain: 'VDIs attached to Control Domain',
  vifOnVmWithNetwork: 'VIF #{vifDevice, number} on {vm} ({network})',
  vifs: 'VIFs',
  vmNameLabel: 'Name',
  vmNameDescription: 'Description',
  vmContainer: 'Resident on',
  snapshotOf: 'Snapshot of',
  legacySnapshots: 'Legacy backups snapshots',
  alarmMessage: 'Alarms',
  noAlarms: 'No alarms',
  alarmDate: 'Date',
  alarmContent: 'Content',
  alarmObject: 'Issue on',
  alarmPool: 'Pool',
  spaceLeftTooltip: '{used}% used ({free} left)',

  // ----- New VM -----
  createVmModalTitle: 'Create VM',
  createVmModalWarningMessage:
    "You're about to use a large amount of resources available on the resource set. Are you sure you want to continue?",
  copyHostBiosStrings: 'Copy host BIOS strings to VM',
  newVmCreateNewVmOn: 'Create a new VM on {select}',
  newVmCreateNewVmNoPermission: 'You have no permission to create a VM',
  newVmInfoPanel: 'Info',
  newVmNameLabel: 'Name',
  newVmTemplateLabel: 'Template',
  newVmDescriptionLabel: 'Description',
  newVmPerfPanel: 'Performance',
  newVmVcpusLabel: 'vCPUs',
  newVmRamLabel: 'RAM',
  newVmRamWarning: 'The memory is below the threshold ({threshold})',
  newVmStaticMaxLabel: 'Static memory max',
  newVmDynamicMinLabel: 'Dynamic memory min',
  newVmDynamicMaxLabel: 'Dynamic memory max',
  newVmInstallSettingsPanel: 'Install settings',
  newVmIsoDvdLabel: 'ISO/DVD',
  newVmNetworkLabel: 'Network',
  newVmInstallNetworkPlaceHolder: 'e.g: http://httpredir.debian.org/debian',
  newVmPvArgsLabel: 'PV Args',
  newVmPxeLabel: 'PXE',
  newVmInterfacesPanel: 'Interfaces',
  newVmMacLabel: 'MAC',
  newVmAddInterface: 'Add interface',
  newVmDisksPanel: 'Disks',
  newVmSrLabel: 'SR',
  newVmSizeLabel: 'Size',
  newVmAddDisk: 'Add disk',
  newVmSummaryPanel: 'Summary',
  newVmCreate: 'Create',
  newVmReset: 'Reset',
  newVmSelectTemplate: 'Select template',
  newVmSshKey: 'SSH key',
  noConfigDrive: 'No config drive',
  newVmCustomConfig: 'Custom config',
  availableTemplateVarsInfo: 'Click here to see the available template variables',
  availableTemplateVarsTitle: 'Available template variables',
  templateNameInfo: 'the VM\'s name. It must not contain "_"',
  templateIndexInfo: "the VM's index, it will take 0 in case of single VM",
  templateEscape: 'Tip: escape any variable with a preceding backslash (\\)',
  coreOsDefaultTemplateError: 'Error on getting the default coreOS cloud template',
  newVmBootAfterCreate: 'Boot VM after creation',
  newVmMacPlaceholder: 'Auto-generated if empty',
  newVmCpuWeightLabel: 'CPU weight',
  newVmDefaultCpuWeight: 'Default: {value, number}',
  newVmCpuCapLabel: 'CPU cap',
  newVmDefaultCpuCap: 'Default: {value, number}',
  newVmCloudConfig: 'Cloud config',
  newVmCreateVms: 'Create VMs',
  newVmCreateVmsConfirm: 'Are you sure you want to create {nbVms, number} VMs?',
  newVmMultipleVms: 'Multiple VMs:',
  newVmMultipleVmsPattern: 'Name pattern:',
  newVmMultipleVmsPatternPlaceholder: 'e.g.: \\{name\\}_%',
  newVmFirstIndex: 'First index:',
  newVmNumberRecalculate: 'Recalculate VMs number',
  newVmNameRefresh: 'Refresh VMs name',
  newVmAffinityHost: 'Affinity host',
  newVmAdvancedPanel: 'Advanced',
  newVmShowAdvanced: 'Show advanced settings',
  newVmHideAdvanced: 'Hide advanced settings',
  newVmShare: 'Share this VM',
  newVmSrsNotOnSameHost: 'The SRs must either be on the same host or shared',
  newVmNetworkConfigLabel: 'Network config',
  newVmNetworkConfigInfo: 'Network configuration is only compatible with the {noCloudDatasourceLink}.',
  newVmNetworkConfigDocLink: 'See {networkConfigDocLink}.',
  newVmNetworkConfigTooltip: 'Click here to get more information about network config',
  newVmUserConfigLabel: 'User config',
  newVmNoCloudDatasource: 'NoCloud datasource',
  newVmNetworkConfigDoc: 'Network config documentation',
  templateHasBiosStrings: 'The template already contains the BIOS strings',
  vmBootFirmwareIsUefi: 'The boot firmware is UEFI',

  // ----- Self -----
  resourceSets: 'Resource sets',
  noResourceSets: 'No resource sets.',
  resourceSetName: 'Resource set name',
  resourceSetUsers: 'Users',
  resourceSetPools: 'Pools',
  resourceSetTemplates: 'Templates',
  resourceSetSrs: 'SRs',
  resourceSetNetworks: 'Networks',
  recomputeResourceSets: 'Recompute all limits',
  saveResourceSet: 'Save',
  resetResourceSet: 'Reset',
  editResourceSet: 'Edit',
  deleteResourceSet: 'Delete',
  deleteResourceSetWarning: 'Delete resource set',
  deleteResourceSetQuestion: 'Are you sure you want to delete this resource set?',
  resourceSetMissingObjects: 'Missing objects:',
  unknownResourceSetValue: 'Unknown',
  availableHosts: 'Available hosts',
  excludedHosts: 'Excluded hosts',
  noHostsAvailable: 'No hosts available.',
  availableHostsDescription: 'VMs created from this resource set shall run on the following hosts.',
  maxCpus: 'Maximum CPUs',
  maxRam: 'Maximum RAM',
  maxDiskSpace: 'Maximum disk space',
  ipPool: 'IP pool',
  quantity: 'Quantity',
  usedResourceLabel: 'Used',
  availableResourceLabel: 'Available',
  resourceSetQuota: 'Used: {usage} (Total: {total})',
  resourceSetNew: 'New',

  // ---- VM import ---
  importVmsList: 'Drop OVA or XVA files here to import Virtual Machines.',
  noSelectedVms: 'No selected VMs.',
  vmImportToPool: 'To Pool:',
  vmImportToSr: 'To SR:',
  vmsToImport: 'VMs to import',
  importVmsCleanList: 'Reset',
  vmImportSuccess: 'VM import success',
  vmImportFailed: 'VM import failed',
  vdiImportSuccess: 'VDI import success',
  vdiImportFailed: 'VDI import failed',
  setVmFailed: 'Error on setting the VM: {vm}',
  startVmImport: 'Import starting…',
  startVdiImport: 'VDI import starting…',
  startVmExport: 'Export starting…',
  startVdiExport: 'VDI export starting…',
  nCpus: 'N CPUs',
  vmMemory: 'Memory',
  diskInfo: 'Disk {position} ({capacity})',
  diskDescription: 'Disk description',
  noDisks: 'No disks.',
  noNetworks: 'No networks.',
  networkInfo: 'Network {name}',
  noVmImportErrorDescription: 'No description available',
  vmImportError: 'Error:',
  vmImportFileType: '{type} file:',
  vmImportConfigAlert: 'Please check and/or modify the VM configuration.',

  // ---- Disk import ---
  diskImportFailed: 'Disk import failed',
  diskImportSuccess: 'Disk import success',
  dropDisksFiles: 'Drop VMDK or VHD files here to import disks.',
  importToSr: 'To SR',

  // ---- Tasks ---
  cancelTask: 'Cancel',
  destroyTask: 'Destroy',
  cancelTasks: 'Cancel selected tasks',
  destroyTasks: 'Destroy selected tasks',
  objects: 'Objects',
  pool: 'Pool',
  task: 'Task',
  progress: 'Progress',
  previousTasks: 'Previous tasks',
  taskLastSeen: 'Last seen',

  // ---- Backup views ---
  backupSchedules: 'Schedules',
  loneSnapshotsMessages: '{nLoneSnapshots} lone snapshot{nLoneSnapshots, plural, one {} other {s}} to delete!',
  scheduleCron: 'Cron pattern',
  scheduleLastRun: 'Click to display last run details',
  scheduleName: 'Name',
  scheduleCopyId: 'Copy ID {id}',
  scheduleTimezone: 'Timezone',
  scheduleExportRetention: 'Backup retention',
  scheduleCopyRetention: 'Replication retention',
  scheduleSnapshotRetention: 'Snapshot retention',
  poolMetadataRetention: 'Pool retention',
  xoMetadataRetention: 'XO retention',
  getRemote: 'Get remote',
  noBackups: 'There are no backups!',
  restoreBackupsInfo: 'Click on a VM to display restore options',
  restoreDeltaBackupsInfo: 'Only the files of Delta Backup which are not on a SMB remote can be restored',
  remoteEnabled: 'Enabled',
  remoteDisabled: 'Disabled',
  enableRemote: 'Enable',
  disableRemote: 'Disable',
  remoteErrorMessage: 'The URL ({url}) is invalid (colon in path). Click this button to change the URL to {newUrl}.',
  backupVmNameColumn: 'VM Name',
  backupVmDescriptionColumn: 'VM Description',
  firstBackupColumn: 'Oldest backup',
  lastBackupColumn: 'Latest backup',
  availableBackupsColumn: 'Available Backups',
  backupRestoreErrorTitle: 'Missing parameters',
  backupRestoreErrorMessage: 'Choose a SR and a backup',
  vmsToBackup: 'VMs to backup',
  refreshBackupList: 'Refresh backup list',
  restoreVmBackups: 'Restore',
  restoreVmBackupsTitle: 'Restore {vm}',
  restoreVmBackupsBulkTitle: 'Restore {nVms, number} VM{nVms, plural, one {} other {s}}',
  restoreVmBackupsBulkMessage:
    'Restore {nVms, number} VM{nVms, plural, one {} other {s}} from {nVms, plural, one {its} other {their}} {oldestOrLatest} backup.',
  restoreMetadataBackupWarning:
    'This operation will overwrite the host metadata. Only perform a metadata restore if it is a new server with nothing running on it.',
  oldest: 'oldest',
  latest: 'latest',
  restoreVmBackupsStart: 'Start VM{nVms, plural, one {} other {s}} after restore',
  restoreVmBackupsBulkErrorTitle: 'Multi-restore error',
  restoreMetadataBackupTitle: 'Restore {item}',
  bulkRestoreMetadataBackupTitle:
    'Restore {nMetadataBackups, number} metadata backup{nMetadataBackups, plural, one {} other {s}}',
  bulkRestoreMetadataBackupMessage:
    'Restore {nMetadataBackups, number} metadata backup{nMetadataBackups, plural, one {} other {s}} from {nMetadataBackups, plural, one {its} other {their}} {oldestOrLatest} backup',
  deleteMetadataBackupTitle: 'Delete {item} backup',
  restoreVmBackupsBulkErrorMessage: 'You need to select a destination SR',
  deleteVmBackups: 'Delete backups…',
  deleteVmBackupsTitle: 'Delete {vm} backups',
  deleteBackupsSelect: 'Select backups to delete:',
  deleteVmBackupsSelectAll: 'All',
  deleteVmBackupsBulkTitle: 'Delete backups',
  deleteVmBackupsBulkMessage:
    'Are you sure you want to delete all the backups from {nVms, number} VM{nVms, plural, one {} other {s}}?',
  deleteVmBackupsBulkConfirmText: 'delete {nBackups} backup{nBackups, plural, one {} other {s}}',
  bulkDeleteMetadataBackupsTitle: 'Delete metadata backups',
  bulkDeleteMetadataBackupsMessage:
    'Are you sure you want to delete all the backups from {nMetadataBackups, number} metadata backup{nMetadataBackups, plural, one {} other {s}}?',
  bulkDeleteMetadataBackupsConfirmText:
    'delete {nMetadataBackups} metadata backup{nMetadataBackups, plural, one {} other {s}}',
  remoteNotCompatibleWithSelectedProxy:
    "The backup will not be run on this remote because it's not compatible with the selected proxy",
  remoteLoadBackupsFailure: 'Loading backups failed',
  remoteLoadBackupsFailureMessage: 'Failed to load backups from {name}.',

  // ----- Restore files view -----
  restoreFiles: 'Restore backup files',
  restoreFilesError: 'Invalid options',
  restoreFilesFromBackup: 'Restore file from {name}',
  restoreFilesSelectBackup: 'Select a backup…',
  restoreFilesSelectDisk: 'Select a disk…',
  restoreFilesSelectPartition: 'Select a partition…',
  restoreFilesSelectFiles: 'Select a file…',
  restoreFilesNoFilesSelected: 'No files selected',
  restoreFilesSelectedFilesAndFolders: 'Selected files/folders ({files}):',
  restoreFilesDiskError: 'Error while scanning disk',
  restoreFilesSelectAllFiles: "Select all this folder's files",
  restoreFilesSelectFolder: 'Select this folder',
  restoreFilesUnselectAll: 'Unselect all files',

  // ----- Modals -----
  emergencyShutdownHostModalTitle: 'Emergency shutdown Host',
  emergencyShutdownHostModalMessage: 'Are you sure you want to shutdown {host}?',
  emergencyShutdownHostsModalTitle: 'Emergency shutdown Host{nHosts, plural, one {} other {s}}',
  emergencyShutdownHostsModalMessage:
    'Are you sure you want to shutdown {nHosts, number} Host{nHosts, plural, one {} other {s}}?',
  stopHostModalTitle: 'Shutdown host',
  stopHostModalMessage:
    "This will shutdown your host. Do you want to continue? If it's the pool master, your connection to the pool will be lost",
  forceStopHost: 'Force shutdown host',
  forceStopHostMessage: 'This will shutdown your host without evacuating its VMs. Do you want to continue?',
  addHostModalTitle: 'Add host',
  addHostModalMessage: 'Are you sure you want to add {host} to {pool}?',
  restartHostModalTitle: 'Restart host',
  restartHostModalMessage: 'This will restart your host. Do you want to continue?',
  restartHostsAgentsModalTitle:
    'Restart Host{nHosts, plural, one {} other {s}} agent{nHosts, plural, one {} other {s}}',
  restartHostsAgentsModalMessage:
    'Are you sure you want to restart {nHosts, number} Host{nHosts, plural, one {} other {s}} agent{nHosts, plural, one {} other {s}}?',
  restartHostsModalTitle: 'Restart Host{nHosts, plural, one {} other {s}}',
  restartHostsModalMessage: 'Are you sure you want to restart {nHosts, number} Host{nHosts, plural, one {} other {s}}?',
  startVmsModalTitle: 'Start VM{vms, plural, one {} other {s}}',
  cloneAndStartVM: 'Start a copy',
  forceStartVm: 'Force start',
  forceStartVmModalTitle: 'Forbidden operation',
  blockedStartVmModalMessage: 'Start operation for this vm is blocked.',
  blockedStartVmsModalMessage: 'Forbidden operation start for {nVms, number} vm{nVms, plural, one {} other {s}}.',
  startVmsModalMessage: 'Are you sure you want to start {vms, number} VM{vms, plural, one {} other {s}}?',
  failedVmsErrorMessage:
    '{nVms, number} vm{nVms, plural, one {} other {s}} are failed. Please see your logs to get more information',
  failedVmsErrorTitle: 'Start failed',
  stopHostsModalTitle: 'Stop Host{nHosts, plural, one {} other {s}}',
  stopHostsModalMessage: 'Are you sure you want to stop {nHosts, number} Host{nHosts, plural, one {} other {s}}?',
  stopVmsModalTitle: 'Stop VM{vms, plural, one {} other {s}}',
  stopVmsModalMessage: 'Are you sure you want to stop {vms, number} VM{vms, plural, one {} other {s}}?',
  restartVmModalTitle: 'Restart VM',
  restartVmModalMessage: 'Are you sure you want to restart {name}?',
  stopVmModalTitle: 'Stop VM',
  stopVmModalMessage: 'Are you sure you want to stop {name}?',
  vmHasNoTools: 'No guest tools',
  vmHasNoToolsMessage: "The VM doesn't have Xen tools installed, which are required to properly stop or reboot it.",
  confirmForceShutdown: 'Would you like to force shutdown the VM?',
  confirmForceReboot: 'Would you like to force reboot the VM?',
  suspendVmsModalTitle: 'Suspend VM{vms, plural, one {} other {s}}',
  suspendVmsModalMessage: 'Are you sure you want to suspend {vms, number} VM{vms, plural, one {} other {s}}?',
  pauseVmsModalTitle: 'Pause VM{vms, plural, one {} other {s}}',
  pauseVmsModalMessage: 'Are you sure you want to pause {vms, number} VM{vms, plural, one {} other {s}}?',
  restartVmsModalTitle: 'Restart VM{vms, plural, one {} other {s}}',
  restartVmsModalMessage: 'Are you sure you want to restart {vms, number} VM{vms, plural, one {} other {s}}?',
  snapshotSaveMemory: 'save memory',
  snapshotVmsModalTitle: 'Snapshot VM{vms, plural, one {} other {s}}',
  deleteVmsModalTitle: 'Delete VM{vms, plural, one {} other {s}}',
  deleteVmsModalMessage:
    'Are you sure you want to delete {vms, number} VM{vms, plural, one {} other {s}}? ALL VM DISKS WILL BE REMOVED',
  deleteVmsConfirmText: 'delete {nVms, number} vm{nVms, plural, one {} other {s}}',
  deleteVmModalTitle: 'Delete VM',
  deleteVmModalMessage: 'Are you sure you want to delete this VM? ALL VM DISKS WILL BE REMOVED',
  deleteVmBlockedModalTitle: 'Blocked operation',
  deleteVmBlockedModalMessage: 'Removing the VM is a blocked operation. Would you like to remove it anyway?',
  forceVmMigrateModalTitle: 'Force migration',
  forceVmMigrateModalMessage:
    'The VM is incompatible with the CPU features of the destination host. Would you like to force it anyway?',
  migrateVmModalTitle: 'Migrate VM',
  migrateVmSelectHost: 'Select a destination host:',
  migrateVmSelectMigrationNetwork: 'Select a migration network:',
  migrateVmSelectNetworks: 'For each VIF, select a network:',
  migrateVmsSelectSr: 'Select a destination SR:',
  migrateVmsSelectSrIntraPool: 'Select a destination SR for local disks:',
  migrateVmsSelectNetwork: 'Select a network on which to connect each VIF:',
  migrateVmsSmartMapping: 'Smart mapping',
  migrateVmVif: 'VIF',
  migrateVmNetwork: 'Network',
  migrateVmNoTargetHost: 'No target host',
  migrateVmNoTargetHostMessage: 'A target host is required to migrate a VM',
  migrateVmNoSr: 'SR required',
  migrateVmNoSrMessage: 'A destination SR is required',
  migrateVmNoDefaultSrError: 'No default SR',
  migrateVmNotConnectedDefaultSrError: 'Default SR not connected to host',
  chooseSrForEachVdisModalSelectSr: 'For each VDI, select an SR (optional)',
  chooseSrForEachVdisModalMainSr: 'Select main SR…',
  chooseSrForEachVdisModalVdiLabel: 'VDI',
  chooseSrForEachVdisModalSrLabel: 'SR*',
  deleteJobsModalTitle: 'Delete job{nJobs, plural, one {} other {s}}',
  deleteJobsModalMessage: 'Are you sure you want to delete {nJobs, number} job{nJobs, plural, one {} other {s}}?',
  deleteVbdsModalTitle: 'Delete VBD{nVbds, plural, one {} other {s}}',
  deleteVbdsModalMessage: 'Are you sure you want to delete {nVbds, number} VBD{nVbds, plural, one {} other {s}}?',
  deleteVdiModalTitle: 'Delete VDI',
  deleteVdiModalMessage: 'Are you sure you want to delete this disk? ALL DATA ON THIS DISK WILL BE LOST',
  deleteVdisModalTitle: 'Delete VDI{nVdis, plural, one {} other {s}}',
  deleteVdisModalMessage:
    'Are you sure you want to delete {nVdis, number} disk{nVdis, plural, one {} other {s}}? ALL DATA ON THESE DISKS WILL BE LOST',
  deleteSchedulesModalTitle: 'Delete schedule{nSchedules, plural, one {} other {s}}',
  deleteSchedulesModalMessage:
    'Are you sure you want to delete {nSchedules, number} schedule{nSchedules, plural, one {} other {s}}?',
  deleteRemotesModalTitle: 'Delete remote{nRemotes, plural, one {} other {s}}',
  deleteRemotesModalMessage:
    'Are you sure you want to delete {nRemotes, number} remote{nRemotes, plural, one {} other {s}}?',
  revertVmModalTitle: 'Revert your VM',
  shareVmInResourceSetModalTitle: 'Share your VM',
  shareVmInResourceSetModalMessage:
    'This VM will be shared with all the members of the self-service {self}. Are you sure?',
  deleteVifsModalTitle: 'Delete VIF{nVifs, plural, one {} other {s}}',
  deleteVifsModalMessage: 'Are you sure you want to delete {nVifs, number} VIF{nVifs, plural, one {} other {s}}?',
  deleteSnapshotModalTitle: 'Delete snapshot',
  deleteSnapshotModalMessage: 'Are you sure you want to delete this snapshot?',
  deleteSnapshotsModalTitle: 'Delete snapshot{nVms, plural, one {} other {s}}',
  deleteSnapshotsModalMessage:
    'Are you sure you want to delete {nVms, number} snapshot{nVms, plural, one {} other {s}}?',
  disconnectVbdsModalTitle: 'Disconnect VBD{nVbds, plural, one {} other {s}}',
  disconnectVbdsModalMessage:
    'Are you sure you want to disconnect {nVbds, number} VBD{nVbds, plural, one {} other {s}}?',
  disableHost: 'Disable host',
  disableHostModalMessage: 'Are you sure you want to disable {host}? This will prevent new VMs from starting.',
  revertVmModalMessage:
    'Are you sure you want to revert this VM to the snapshot state? This operation is irreversible.',
  revertVmModalSnapshotBefore: 'Snapshot before',
  importBackupModalSelectBackup: 'Select your backup…',
  importBackupModalSelectSr: 'Select a destination SR…',
  deleteOrphanedVdisModalTitle: 'Delete orphaned snapshot VDIs',
  deleteOrphanedVdisModalMessage:
    'Are you sure you want to delete {nVdis, number} orphaned snapshot VDI{nVdis, plural, one {} other {s}}?',
  definitiveMessageModal: 'This operation is definitive.',
  existingLunModalTitle: 'Previous LUN Usage',
  existingLunModalText:
    'This LUN has been previously used as storage by a XenServer host. All data will be lost if you choose to continue with the SR creation.',
  alreadyRegisteredModal: 'Replace current registration?',
  alreadyRegisteredModalText:
    'Your XO appliance is already registered to {email}, do you want to forget and replace this registration ?',
  trialReadyModal: 'Ready for trial?',
  trialReadyModalText:
    'During the trial period, XOA need to have a working internet connection. This limitation does not apply for our paid plans!',
  cancelTasksModalTitle: 'Cancel task{nTasks, plural, one {} other {s}}',
  cancelTasksModalMessage: 'Are you sure you want to cancel {nTasks, number} task{nTasks, plural, one {} other {s}}?',
  destroyTasksModalTitle: 'Destroy task{nTasks, plural, one {} other {s}}',
  destroyTasksModalMessage: 'Are you sure you want to destroy {nTasks, number} task{nTasks, plural, one {} other {s}}?',
  forgetHostFromSrModalTitle: 'Forget host',
  forgetHostFromSrModalMessage:
    'Are you sure you want to forget this host? This will disconnect the SR from the host by removing the link between them (PBD).',
  forgetHostsFromSrModalTitle: 'Forget host{nPbds, plural, one {} other {s}}',
  forgetHostsFromSrModalMessage:
    'Are you sure you want to forget {nPbds, number} host{nPbds, plural, one {} other {s}}? This will disconnect the SR from these hosts by removing the links between the SR and the hosts (PBDs).',
  forgetSrFromHostModalTitle: 'Forget SR',
  forgetSrFromHostModalMessage:
    'Are you sure you want to forget this SR? This will disconnect the SR from the host by removing the link between them (PBD).',
  forgetSrsFromHostModalTitle: 'Forget SR{nPbds, plural, one {} other {s}}',
  forgetSrsFromHostModalMessage:
    'Are you sure you want to forget {nPbds, number} SR{nPbds, plural, one {} other {s}}? This will disconnect the SRs from the host by removing the links between the host and the SRs (PBDs).',
  optionalEntry: '* optional',
  vmWithDuplicatedMacAddressesMessage:
    'This VM contains a duplicate MAC address or has the same MAC address as another running VM. Do you want to continue?',
  vmsWithDuplicatedMacAddressesMessage:
    '{nVms, number} VM{nVms, plural, one {} other {s}} contain{nVms, plural, one {s} other {}} duplicate MAC addresses or {nVms, plural, one {has} other {have}} the same MAC addresses as other running VMs. Do you want to continue?',

  // ----- Servers -----
  enableServerErrorTitle: 'Enable server',
  enableServerErrorMessage: 'Unexpected response. Please check your server address.',
  serverLabel: 'Label',
  serverHost: 'Host',
  serverUsername: 'Username',
  serverPassword: 'Password',
  serverReadOnly: 'Read Only',
  serverUnauthorizedCertificates: 'Unauthorized Certificates',
  serverAllowUnauthorizedCertificates: 'Allow Unauthorized Certificates',
  serverUnauthorizedCertificatesInfo:
    "Enable it if your certificate is rejected, but it's not recommended because your connection will not be secured.",
  serverPlaceHolderUser: 'username',
  serverPlaceHolderPassword: 'password',
  serverPlaceHolderAddress: 'address[:port]',
  serverPlaceHolderLabel: 'label',
  serverConnect: 'Connect',
  serverError: 'Error',
  serverAddFailed: 'Adding server failed',
  serverStatus: 'Status',
  serverConnectionFailed: 'Connection failed. Click for more information.',
  serverAuthFailed: 'Authentication error',
  serverUnknownError: 'Unknown error',
  serverSelfSignedCertError: 'Invalid self-signed certificate',
  serverSelfSignedCertQuestion:
    'Do you want to accept self-signed certificate for this server even though it would decrease security?',
  serverEnable: 'Enable',
  serverEnabled: 'Enabled',
  serverDisabled: 'Disabled',
  serverDisable: 'Disable server',
  serverHttpProxy: ' HTTP proxy URL',
  serverHttpProxyPlaceHolder: ' HTTP proxy URL',

  // ----- Copy VM -----
  copyVm: 'Copy VM',
  copyVmName: 'Name',
  copyVmNamePatternPlaceholder: 'e.g.: "\\{name\\}_COPY"',
  copyVmSelectSr: 'Select SR',
  copyVmsNoTargetSr: 'No target SR',
  copyVmsNoTargetSrMessage: 'A target SR is required to copy a VM',
  notSupportedZstdWarning: 'Zstd is not supported on {nVms, number} VM{nVms, plural, one {} other {s}}',
  notSupportedZstdTooltip: 'Click to see the concerned VMs',
  fastCloneMode: 'Fast clone',
  fullCopyMode: 'Full copy',
  copyTemplate: 'Copy template',

  // ----- Detach host -----
  detachHostModalTitle: 'Detach host',
  detachHostModalMessage:
    'Are you sure you want to detach {host} from its pool? THIS WILL REMOVE ALL VMs ON ITS LOCAL STORAGE AND REBOOT THE HOST.',
  detachHost: 'Detach',

  // ----- Advanced Live Telemetry -----
  advancedLiveTelemetry: 'Advanced Live Telemetry',
  pluginNetDataIsNecessary: 'Netdata plugin is necessary',
  enableAdvancedLiveTelemetry: 'Enable Advanced Live Telemetry',
  enableAdvancedLiveTelemetrySuccess: 'Advanced Live Telemetry successfully enabled',
  xcpOnlyFeature: 'This feature is only XCP-ng compatible',

  // ----- Forget host -----
  forgetHostModalTitle: 'Forget host',
  forgetHostModalMessage:
    "Are you sure you want to forget {host} from its pool? Be sure this host can't be back online, or use detach instead.",
  forgetHost: 'Forget',

  // ----- Set pool master -----

  setPoolMasterModalTitle: 'Designate a new master',
  setPoolMasterModalMessage: 'This operation may take several minutes. Do you want to continue?',

  // ----- Network -----
  networkManagement: 'Management',
  newNetworkCreate: 'Create network',
  newNetworkInterface: 'Interface',
  newNetworkName: 'Name',
  newNetworkDescription: 'Description',
  newNetworkVlan: 'VLAN',
  newNetworkDefaultVlan: 'No VLAN if empty',
  newNetworkMtu: 'MTU',
  newNetworkDefaultMtu: 'Default: 1500',
  newNetworkBondMode: 'Bond mode',
  newNetworkInfo: 'Info',
  newNetworkType: 'Type',
  newNetworkPreferredCenter: 'Preferred center (optional)',
  newNetworkEncapsulation: 'Encapsulation',
  newNetworkEncrypted: 'Encrypted',
  encryptionWarning: 'A pool can have 1 encrypted GRE network and 1 encrypted VxLAN network max',
  preferredCenterTip: 'The host to try first to elect as center of the network',
  newNetworkSdnControllerTip: 'Please see the requirements',
  deleteNetwork: 'Delete network',
  deleteNetworkConfirm: 'Are you sure you want to delete this network?',
  networkInUse: 'This network is currently in use',
  pillBonded: 'Bonded',
  bondedNetwork: 'Bonded network',
  privateNetwork: 'Private network',
  addPool: 'Add pool',

  // ----- Add host -----
  hosts: 'Hosts',
  addHostNoHost: 'No host',
  addHostNoHostMessage: 'No host selected to be added',

  // ----- About View -----
  xenOrchestraServer: 'Xen Orchestra server',
  xenOrchestraWeb: 'Xen Orchestra web client',
  noProSupport: 'Professional support missing!',
  productionUse: 'Want to use in production?',
  getSupport: 'Get pro support with the Xen Orchestra Appliance at {website}',
  bugTracker: 'Bug Tracker',
  bugTrackerText: 'Issues? Report it!',
  community: 'Community',
  communityText: 'Join our community forum!',
  freeTrial: 'Free Trial for Premium Edition!',
  freeTrialNow: 'Request your trial now!',
  issues: 'Any issue?',
  issuesText: 'Problem? Contact us!',
  documentation: 'Documentation',
  documentationText: 'Read our official doc',
  proSupportIncluded: 'Pro support included',
  xoAccount: 'Access your XO Account',
  openTicket: 'Report a problem',
  openTicketText: 'Problem? Open a ticket!',

  // ----- Upgrade Panel -----
  upgradeNeeded: 'Upgrade needed',
  upgradeNow: 'Upgrade now!',
  or: 'Or',
  tryIt: 'Try it for free!',
  availableIn: 'This feature is available starting from {plan} Edition',
  notAvailable: 'This feature is not available in your version, contact your administrator to know more.',

  // ----- Updates View -----
  registration: 'Registration',
  settings: 'Settings',
  proxySettings: 'Proxy settings',
  proxySettingsHostPlaceHolder: 'Host (myproxy.example.org)',
  proxySettingsPortPlaceHolder: 'Port (eg: 3128)',
  proxySettingsUsernamePlaceHolder: 'Username',
  proxySettingsPasswordPlaceHolder: 'Password',
  updateRegistrationEmailPlaceHolder: 'Your email account',
  updateRegistrationPasswordPlaceHolder: 'Your password',
  updaterTroubleshootingLink: 'Troubleshooting documentation',
  update: 'Update',
  refresh: 'Refresh',
  upgrade: 'Upgrade',
  downgrade: 'Downgrade',
  considerSubscribe:
    'Please consider subscribing and trying it with all the features for free during 15 days on {link}.',
  currentVersion: 'Current version:',
  register: 'Register',
  editRegistration: 'Edit registration',
  trialRegistration: 'Please, take time to register in order to enjoy your trial.',
  trialStartButton: 'Start trial',
  trialAvailableUntil: 'You can use a trial version until {date, date, medium}. Upgrade your appliance to get it.',
  trialConsumed: 'Your trial has been ended. Contact us or downgrade to Free version',
  trialLocked: 'Your xoa-updater service appears to be down. Your XOA cannot run fully without reaching this service.',
  noUpdateInfo: 'No update information available',
  waitingUpdateInfo: 'Update information may be available',
  upToDate: 'Your XOA is up-to-date',
  mustUpgrade: 'You need to update your XOA (new version is available)',
  registerNeeded: 'Your XOA is not registered for updates',
  updaterError: "Can't fetch update information",
  promptUpgradeReloadTitle: 'Upgrade successful',
  promptUpgradeReloadMessage:
    'Your XOA has successfully upgraded, and your browser must reload the application. Do you want to reload now ?',
  upgradeWarningTitle: 'Upgrade warning',
  upgradeWarningMessage:
    'You have some backup jobs in progress. If you upgrade now, these jobs will be interrupted! Are you sure you want to continue?',
  releaseChannels: 'Release channels',
  unlistedChannel: 'unlisted channel',
  unlistedChannelName: 'Unlisted channel name',
  selectChannel: 'Select channel',
  changeChannel: 'Change channel',
  updaterCommunity: 'The Web updater, the release channels and the proxy settings are available in XOA.',
  xoaBuild: 'XOA build:',

  // ----- OS Disclaimer -----
  disclaimerTitle: 'Xen Orchestra from the sources',
  disclaimerText1: "You are using XO from the sources! That's great for a personal/non-profit usage.",
  disclaimerText2: "If you are a company, it's better to use it with our appliance + pro support included:",
  disclaimerText3: 'This version is not bundled with any support nor updates. Use it with caution.',
  disclaimerText4: 'Why do I see this message?',
  notRegisteredDisclaimerInfo: 'You are not registered. Your XOA may not be up to date.',
  notRegisteredDisclaimerCreateAccount: 'Click here to create an account.',
  notRegisteredDisclaimerRegister: 'Click here to register and update your XOA.',

  // ----- PIF -----
  connectPif: 'Connect PIF',
  connectPifConfirm: 'Are you sure you want to connect this PIF?',
  disconnectPif: 'Disconnect PIF',
  disconnectPifConfirm: 'Are you sure you want to disconnect this PIF?',
  deletePif: 'Delete PIF',
  deletePifConfirm: 'Are you sure you want to delete this PIF?',
  deletePifs: 'Delete PIFs',
  deletePifsConfirm: 'Are you sure you want to delete {nPifs, number} PIF{nPifs, plural, one {} other {s}}?',
  pifConnected: 'Connected',
  pifDisconnected: 'Disconnected',
  pifPhysicallyConnected: 'Physically connected',
  pifPhysicallyDisconnected: 'Physically disconnected',

  // ----- User -----
  username: 'Username',
  password: 'Password',
  language: 'Language',
  oldPasswordPlaceholder: 'Old password',
  newPasswordPlaceholder: 'New password',
  confirmPasswordPlaceholder: 'Confirm new password',
  confirmationPasswordError: 'Confirmation password incorrect',
  confirmationPasswordErrorBody: 'Password does not match the confirm password.',
  pwdChangeSuccess: 'Password changed',
  pwdChangeSuccessBody: 'Your password has been successfully changed.',
  pwdChangeError: 'Incorrect password',
  pwdChangeErrorBody: 'The old password provided is incorrect. Your password has not been changed.',
  changePasswordOk: 'OK',
  forgetTokens: 'Forget all connection tokens',
  forgetTokensExplained:
    'This will prevent other clients from authenticating with existing tokens but will not kill active sessions',
  forgetTokensSuccess: 'Successfully forgot connection tokens',
  forgetTokensError: 'Error while forgetting connection tokens',
  sshKeys: 'SSH keys',
  newSshKey: 'New SSH key',
  deleteSshKey: 'Delete',
  deleteSshKeys: 'Delete selected SSH keys',
  newSshKeyModalTitle: 'New SSH key',
  sshKeyAlreadyExists: 'SSH key already exists!',
  sshKeyErrorTitle: 'Invalid key',
  sshKeyErrorMessage: 'An SSH key requires both a title and a key.',
  title: 'Title',
  key: 'Key',
  deleteSshKeyConfirm: 'Delete SSH key',
  deleteSshKeyConfirmMessage: 'Are you sure you want to delete the SSH key {title}?',
  deleteSshKeysConfirm: 'Delete SSH key{nKeys, plural, one {} other {s}}',
  deleteSshKeysConfirmMessage:
    'Are you sure you want to delete {nKeys, number} SSH key{nKeys, plural, one {} other {s}}?',
  addOtpConfirm: 'Add OTP authentication',
  addOtpConfirmMessage: 'Are you sure you want to add OTP authentication?',
  removeOtpConfirm: 'Remove OTP authentication',
  removeOtpConfirmMessage: 'Are you sure you want to remove OTP authentication?',
  OtpAuthentication: 'OTP authentication',

  // ----- Usage -----
  others: '{nOthers, number} other{nOthers, plural, one {} other {s}}',

  // ----- Logs -----
  logUser: 'User',
  logMessage: 'Message',
  logSuggestXcpNg: 'Use XCP-ng to get rid of restrictions',
  logXapiError: 'This is a XenServer/XCP-ng error',
  logError: 'Error',
  logTitle: 'Logs',
  logDisplayDetails: 'Display details',
  logDownload: 'Download log',
  logTime: 'Date',
  logDelete: 'Delete log',
  logsDelete: 'Delete logs',
  logsJobId: 'Job ID',
  logsJobName: 'Job name',
  logsBackupTime: 'Backup time',
  logsRestoreTime: 'Restore time',
  copyLogToClipboard: 'Copy log to clipboard',
  logsVmNotFound: 'VM not found!',
  logsFailedRestoreError: 'Click to show error',
  logsFailedRestoreTitle: 'Restore error',
  logDeleteMultiple: 'Delete log{nLogs, plural, one {} other {s}}',
  logDeleteMultipleMessage: 'Are you sure you want to delete {nLogs, number} log{nLogs, plural, one {} other {s}}?',
  logIndicationToEnable: 'Click to enable',
  logIndicationToDisable: 'Click to disable',
  reportBug: 'Report a bug',
  unhealthyVdiChainError: 'Job canceled to protect the VDI chain',
  backupRestartVm: "Restart VM's backup",
  backupForceRestartVm: "Force restart VM's backup",
  backupRestartFailedVms: "Restart failed VMs' backup",
  backupForceRestartFailedVms: "Force restart failed VMs' backup",
  clickForMoreInformation: 'Click for more information',
  goToThisJob: 'Click to go to this job',
  goToCorrespondingLogs: 'Click to see corresponding logs',

  // ----- IPs ------
  ipPoolName: 'Name',
  ipPoolIps: 'IPs',
  ipPoolNetworks: 'Networks',
  ipsNoIpPool: 'No IP pools',
  ipsCreate: 'Create',
  ipsVifs: 'VIFs',
  ipsNotUsed: 'Not used',
  ipPoolUnknownVif: 'unknown VIF',
  ipPoolNameAlreadyExists: 'Name already exists',

  // ----- Shortcuts -----
  shortcutModalTitle: 'Keyboard shortcuts',
  shortcut_XoApp: 'Global',
  shortcut_XoApp_GO_TO_HOSTS: 'Go to hosts list',
  shortcut_XoApp_GO_TO_POOLS: 'Go to pools list',
  shortcut_XoApp_GO_TO_VMS: 'Go to VMs list',
  shortcut_XoApp_GO_TO_SRS: 'Go to SRs list',
  shortcut_XoApp_CREATE_VM: 'Create a new VM',
  shortcut_XoApp_UNFOCUS: 'Unfocus field',
  shortcut_XoApp_HELP: 'Show shortcuts key bindings',
  shortcut_Home: 'Home',
  shortcut_Home_SEARCH: 'Focus search bar',
  shortcut_Home_NAV_DOWN: 'Next item',
  shortcut_Home_NAV_UP: 'Previous item',
  shortcut_Home_SELECT: 'Select item',
  shortcut_Home_JUMP_INTO: 'Open',
  shortcut_SortedTable: 'Supported tables',
  shortcut_SortedTable_SEARCH: 'Focus the table search bar',
  shortcut_SortedTable_NAV_DOWN: 'Next item',
  shortcut_SortedTable_NAV_UP: 'Previous item',
  shortcut_SortedTable_SELECT: 'Select item',
  shortcut_SortedTable_ROW_ACTION: 'Action',

  // ----- Settings/ACLs -----
  settingsAclsButtonTooltipVM: 'VM',
  settingsAclsButtonTooltiphost: 'Hosts',
  settingsAclsButtonTooltippool: 'Pool',
  settingsAclsButtonTooltipSR: 'SR',
  settingsAclsButtonTooltipnetwork: 'Network',

  // ----- Settings/Cloud configs -----
  settingsCloudConfigTemplate: 'Template',
  confirmDeleteCloudConfigsTitle: 'Delete cloud config{nCloudConfigs, plural, one {} other {s}}',
  confirmDeleteCloudConfigsBody:
    'Are you sure you want to delete {nCloudConfigs, number} cloud config{nCloudConfigs, plural, one {} other {s}}?',
  deleteCloudConfig: 'Delete cloud config',
  editCloudConfig: 'Edit cloud config',
  deleteSelectedCloudConfigs: 'Delete selected cloud configs',

  // ----- Config -----
  noConfigFile: 'No config file selected',
  importTip: 'Try dropping a config file here or click to select a config file to upload.',
  config: 'Config',
  importConfig: 'Import',
  importConfigEnterPassphrase: 'If the config is encrypted, please enter the passphrase:',
  importConfigSuccess: 'Config file successfully imported',
  importConfigError: 'Error while importing config file',
  exportConfig: 'Export',
  exportConfigEnterPassphrase: 'If you want to encrypt the exported config, please enter a passphrase:',
  downloadConfig: 'Download current config',

  // ----- SR -----
  disabledVdiMigrateTooltip: "Snapshots and base copies can't be migrated individually",
  srReconnectAllModalTitle: 'Reconnect all hosts',
  srReconnectAllModalMessage: 'This will reconnect this SR to all its hosts.',
  srDisconnectAllModalTitle: 'Disconnect all hosts',
  srDisconnectAllModalMessage: 'This will disconnect this SR from all its hosts.',
  srsDisconnectAllModalMessage:
    'This will disconnect each selected SR from its host (local SR) or from every hosts of its pool (shared SR).',
  srForgetModalTitle: 'Forget SR',
  srsForgetModalTitle: 'Forget selected SRs',
  srForgetModalMessage: "Are you sure you want to forget this SR? VDIs on this storage won't be removed.",
  srsForgetModalMessage:
    "Are you sure you want to forget all the selected SRs? VDIs on these storages won't be removed.",
  srAllDisconnected: 'Disconnected',
  srSomeConnected: 'Partially connected',
  srAllConnected: 'Connected',
  migrateSelectedVdis: 'Migrate selected VDIs',
  migrateVdiMessage:
    'All the VDIs attached to a VM must either be on a shared SR or on the same host (local SR) for the VM to be able to start.',

  // ----- XOSAN -----
  xosanTitle: 'XOSAN',
  xosanSuggestions: 'Suggestions',
  xosanDisperseWarning: 'Warning: using disperse layout is not recommended right now. Please read {link}.',
  xosanName: 'Name',
  xosanHost: 'Host',
  xosanHosts: 'Connected Hosts',
  xosanPool: 'Pool',
  xosanSize: 'Size',
  xosanUsedSpace: 'Used space',
  xosanLicense: 'License',
  xosanMultipleLicenses: 'This XOSAN has more than 1 license!',
  xosanNeedPack: 'XOSAN pack needs to be installed and up to date on each host of the pool.',
  xosanInstallIt: 'Install it now!',
  xosanNeedRestart: 'Some hosts need their toolstack to be restarted before you can create an XOSAN',
  xosanRestartAgents: 'Restart toolstacks',
  xosanSrOnSameHostMessage: 'Select no more than 1 SR per host',
  xosanLayout: 'Layout',
  xosanRedundancy: 'Redundancy',
  xosanCapacity: 'Capacity',
  xosanAvailableSpace: 'Available space',
  xosanDiskLossLegend: '* Can fail without data loss',
  xosanCreate: 'Create',
  xosanCommunity: 'XOSAN is available in XOA',
  xosanNew: 'New',
  xosanAdvanced: 'Advanced',
  xosanRemoveSubvolumes: 'Remove subvolumes',
  xosanAddSubvolume: 'Add subvolume…',
  xosanWarning:
    "This version of XOSAN SR is from the first beta phase. You can keep using it, but to modify it you'll have to save your disks and re-create it.",
  xosanVlan: 'VLAN',
  xosanNoSrs: 'No XOSAN found',
  xosanPbdsDetached: 'Some SRs are detached from the XOSAN',
  xosanBadStatus: 'Something is wrong with: {badStatuses}',
  xosanRunning: 'Running',
  xosanUpdatePacks: 'Update packs',
  xosanPackUpdateChecking: 'Checking for updates',
  xosanPackUpdateError:
    'Error while checking XOSAN packs. Please make sure that the Cloud plugin is installed and loaded, and that the updater is reachable.',
  xosanPackUpdateUnavailable: 'XOSAN resources are unavailable',
  xosanPackUpdateUnregistered: 'Not registered for XOSAN resources',
  xosanPackUpdateUpToDate: "✓ This pool's XOSAN packs are up to date!",
  xosanPackUpdateVersion: 'Update pool with latest pack v{version}',
  xosanDelete: 'Delete XOSAN',
  xosanFixIssue: 'Fix',
  xosanCreatingOn: 'Creating XOSAN on {pool}',
  xosanState_configuringNetwork: 'Configuring network…',
  xosanState_importingVm: 'Importing VM…',
  xosanState_copyingVms: 'Copying VMs…',
  xosanState_configuringVms: 'Configuring VMs…',
  xosanState_configuringGluster: 'Configuring gluster…',
  xosanState_creatingSr: 'Creating SR…',
  xosanState_scanningSr: 'Scanning SR…',
  xosanXcpngWarning:
    'XOSAN cannot be installed on XCP-ng yet. Incoming XOSANv2 will be compatible with XCP-ng: {link}.',
  // Pack download modal
  xosanInstallCloudPlugin: 'Install XOA plugin first',
  xosanLoadCloudPlugin: 'Load XOA plugin first',
  xosanNoPackFound: 'No compatible XOSAN pack found for your XenServer versions.',
  // SR tab XOSAN
  xosanVmsNotRunning: 'Some XOSAN Virtual Machines are not running',
  xosanVmsNotFound: 'Some XOSAN Virtual Machines could not be found',
  xosanFilesNeedingHealing: 'Files needing healing',
  xosanFilesNeedHealing: 'Some XOSAN Virtual Machines have files needing healing',
  xosanHostNotInNetwork: 'Host {hostName} is not in XOSAN network',
  xosanVm: 'VM controller',
  xosanUnderlyingStorage: 'SR',
  xosanReplace: 'Replace…',
  xosanOnSameVm: 'On same VM',
  xosanBrickName: 'Brick name',
  xosanBrickUuid: 'Brick UUID',
  xosanBrickSize: 'Brick size',
  xosanMemorySize: 'Memory size',
  xosanStatus: 'Status',
  xosanArbiter: 'Arbiter',
  xosanUsedInodes: 'Used Inodes',
  xosanBlockSize: 'Block size',
  xosanDevice: 'Device',
  xosanFsName: 'FS name',
  xosanMountOptions: 'Mount options',
  xosanPath: 'Path',
  xosanJob: 'Job',
  xosanPid: 'PID',
  xosanPort: 'Port',
  xosanReplaceBrickErrorTitle: 'Missing values',
  xosanReplaceBrickErrorMessage: 'You need to select a SR and a size',
  xosanAddSubvolumeErrorTitle: 'Bad values',
  xosanAddSubvolumeErrorMessage: 'You need to select {nSrs, number} and a size',
  xosanSelectNSrs: 'Select {nSrs, number} SRs',
  xosanRun: 'Run',
  xosanRemove: 'Remove',
  xosanVolume: 'Volume',
  xosanVolumeOptions: 'Volume options',
  xosanCouldNotFindVm: 'Could not find VM',
  xosanUnderlyingStorageUsage: 'Using {usage}',
  xosanCustomIpNetwork: 'Custom IP network (/24)',
  xosanIssueHostNotInNetwork: 'Will configure the host xosan network device with a static IP address and plug it in.',

  // Hub
  hubPage: 'Hub',
  hubCommunity: 'Hub is available in XOA',
  noDefaultSr: 'The selected pool has no default SR',
  successfulInstall: 'VM installed successfully',
  vmNoAvailable: 'No VMs available ',
  create: 'Create',
  hubResourceAlert: 'Resource alert',
  os: 'OS',
  version: 'Version',
  size: 'Size',
  totalDiskSize: 'Total disk size',
  hideInstalledPool: 'Already installed templates are hidden',
  hubImportNotificationTitle: 'XVA import',
  hubTemplateDescriptionNotAvailable: 'No description available for this template',
  recipeCreatedSuccessfully: 'Recipe created successfully',
  recipeViewCreatedVms: 'View created VMs',
  templatesLabel: 'Templates',
  recipesLabel: 'Recipes',
  network: 'Network',
  recipeMasterNameLabel: 'Master name',
  recipeNumberOfNodesLabel: 'Number of nodes',
  recipeSshKeyLabel: 'SSH key',
  recipeNetworkCidr: 'Network CIDR',

  // Audit
  auditActionEvent: 'Action/Event',
  auditAlteredRecord: 'The record ({ id }) was altered ({ n, number } valid records)',
  auditCheckIntegrity: 'Check integrity',
  auditCopyFingerprintToClipboard: 'Copy fingerprint to clipboard',
  auditGenerateNewFingerprint: 'Generate a new fingerprint',
  auditMissingRecord: 'The record ({ id }) is missing ({ n, number } valid records)',
  auditEnterFingerprint: 'Fingerprint',
  auditEnterFingerprintInfo:
    "Enter the saved fingerprint to check the previous logs' integrity. If you don't have any, click OK.",
  auditRecord: 'Audit record',
  auditIntegrityVerified: 'Integrity verified',
  auditSaveFingerprintInfo: 'Keep this fingerprint to be able to check the integrity of the current records later.',
  auditSaveFingerprintInErrorInfo:
    'However, if you trust the current state of the records, keep this fingerprint to be able to check their integrity later.',
  auditNewFingerprint: 'New fingerprint',
  downloadAuditRecords: 'Download records',
  displayAuditRecord: 'Display record',
  noAuditRecordAvailable: 'No audit record available',
  refreshAuditRecordsList: 'Refresh records list',
  auditInactiveUserActionsRecord: 'User actions recording is currently inactive',

  // Licenses
  xosanUnregisteredDisclaimer:
    'You are not registered and therefore will not be able to create or manage your XOSAN SRs. {link}',
  xosanSourcesDisclaimer:
    'In order to create a XOSAN SR, you need to use the Xen Orchestra Appliance and buy a XOSAN license on {link}.',
  registerNow: 'Register now!',
  licensesUnregisteredDisclaimer: 'You need to register your appliance to manage your licenses.',
  licenseProduct: 'Product',
  licensePurchaser: 'Purchaser',
  licenseExpires: 'Expires',
  licensePurchaserYou: 'You',
  productSupport: 'Support',
  licenseNotBoundXosan: 'No XOSAN attached',
  licenseNotBoundProxy: 'No proxy attached',
  licenseBoundUnknownXosan: 'License attached to an unknown XOSAN',
  licenseBoundUnknownProxy: 'License attached to an unknown proxy',
  licensesManage: 'Manage the licenses',
  newLicense: 'New license',
  refreshLicenses: 'Refresh',
  xosanLicenseRestricted: 'Limited size because XOSAN is in trial',
  xosanAdminNoLicenseDisclaimer: 'You need a license on this SR to manage the XOSAN.',
  xosanAdminExpiredLicenseDisclaimer:
    'Your XOSAN license has expired. You can still use the SR but cannot administrate it anymore.',
  xosanCheckLicenseError: 'Could not check the license on this XOSAN SR',
  xosanGetLicensesError: 'Could not fetch licenses',
  licenseHasExpired: 'License has expired.',
  licenseBoundToOtherXoa: 'License bound to another XOA',
  licenseBoundToThisXoa: 'This license is active on this XOA',
  xosanLicenseExpiresDate: 'License expires on {date}.',
  xosanUpdateLicenseMessage: 'Update the license now!',
  xosanUnknownSr: 'Unknown XOSAN SR.',
  contactUs: 'Contact us!',
  xosanNoLicense: 'No license.',
  xosanUnlockNow: 'Unlock now!',
  selectLicense: 'Select a license',
  bindLicense: 'Bind license',
  expiresOn: 'expires on {date}',
  xosanInstallXoaPlugin: 'Install XOA plugin first',
  xosanLoadXoaPlugin: 'Load XOA plugin first',
  bindXoaLicense: 'Activate license',
  rebindXoaLicense: 'Move license to this XOA',
  bindXoaLicenseConfirm: 'Are you sure you want to activate this license on your XOA? This action is not reversible!',
  bindXoaLicenseConfirmText: 'activate {licenseType} license',
  updateNeeded: 'Update needed',
  starterLicense: 'Starter license',
  enterpriseLicense: 'Enterprise license',
  premiumLicense: 'Premium license',
  trialLicenseInfo: 'You are currently in a {edition} trial period that will end on {date, date, medium}',

  // ----- proxies -----
  forgetProxyApplianceTitle: 'Forget prox{n, plural, one {y} other {ies}}',
  forgetProxyApplianceMessage: 'Are you sure you want to forget {n, number} prox{n, plural, one {y} other {ies}}?',
  forgetProxies: 'Forget proxy(ies)',
  destroyProxyApplianceTitle: 'Destroy prox{n, plural, one {y} other {ies}}',
  destroyProxyApplianceMessage: 'Are you sure you want to destroy {n, number} prox{n, plural, one {y} other {ies}}?',
  destroyProxies: 'Destroy proxy(ies)',
  deployProxy: 'Deploy a proxy',
  redeployProxy: 'Redeploy proxy',
  redeployProxyAction: 'Redeploy this proxy',
  redeployProxyWarning: 'This action will destroy the old proxy VM',
  noProxiesAvailable: 'No proxies available',
  checkProxyHealth: 'Test your proxy',
  updateProxyApplianceSettings: 'Update appliance settings',
  proxyTestSuccess: 'Test passed for {name}',
  proxyTestSuccessMessage: 'The proxy appears to work correctly',
  proxyTestFailed: 'Test failed for {name}',
  proxyTestFailedConnectionIssueMessage: 'Unable to connect to this proxy',
  proxyLinkedRemotes: 'Click to see linked remotes',
  proxyLinkedBackups: 'Click to see linked backups',
  proxyNetworkDnsPlaceHolder: 'Default to: {dns}',
  proxyNetworkNetmaskPlaceHolder: 'Default to: {netmask}',
  proxySrPredicateInfo: 'The select only contains SRs connected to at least one HVM-capable host',
  httpProxy: 'HTTP proxy',
  httpProxyPlaceholder: 'protocol://username:password@address:port',
  proxyUpgradesError: 'Unable to check upgrades availability',
  proxyApplianceSettingsInfo: 'Leave the field empty and click on OK to remove the existing configuration',
  proxyUpToDate: 'Your proxy is up-to-date',
  proxyRunningBackupsMessage:
    'The upgrade will interrupt {nJobs, number} running backup job{nJobs, plural, one {} other {s}}. Do you want to continue?',
  proxiesNeedUpgrade: 'Some proxies need to be upgraded.',
  upgradeNeededForProxies: 'Some proxies need to be upgraded. Click here to get more information.',

  // ----- Utils -----
  secondsFormat: '{seconds, plural, one {# second} other {# seconds}}',
  durationFormat:
    '{days, plural, =0 {} one {# day } other {# days }}{hours, plural, =0 {} one {# hour } other {# hours }}{minutes, plural, =0 {} one {# minute } other {# minutes }}{seconds, plural, =0 {} one {# second} other {# seconds}}',
}
forEach(messages, function (message, id) {
  if (typeof message === 'string') {
    messages[id] = {
      id,
      defaultMessage: message,
    }
  } else if (!message.id) {
    message.id = id
  }
})

module.exports = messages
